/*
 * Copyright (c) [2012] Samsung Electronics Co., Ltd.
 *
 * Licensed under the Flora License, Version 1.1 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */



#ifndef _MP_UTIL_DATABASE_
#define _MP_UTIL_DATABASE_

#include "video-player.h"
#include <glib.h>

typedef enum
{
	MP_MEDIA_VIDEO_FILE_TYPE			= 0,
	MP_MEDIA_CAMERA_FILE_TYPE,
	MP_MEDIA_ALL_FILE_TYPE,
	MP_MEDIA_FILE_TYPE_MAX,
}MpMediaSvcVideoFileType;

typedef enum
{
	MP_MEDIA_SORT_BY_NONE				= 0,
	MP_MEDIA_SORT_BY_NAME_ASC,
	MP_MEDIA_SORT_BY_NAME_DESC,
	MP_MEDIA_SORT_BY_DATE_MOST_RECENT,
	MP_MEDIA_SORT_BY_OLDEST,
	MP_MEDIA_SORT_BY_MAX,
}MpMediaSvcSortType;

typedef enum
{
	MP_MEDIA_LIST_TYPE_FOLDER			= 0,
	MP_MEDIA_LIST_TYPE_ALL_FOLDER_GALLERY,
	MP_MEDIA_LIST_TYPE_TAG_GALLERY,
	MP_MEDIA_LIST_TYPE_FAVORITE,
	MP_MEDIA_LIST_TYPE_ALLSHARE,
	MP_MEDIA_LIST_TYPE_MAX,
}MpMediaSvcListType;


void MpUtilMediaSvcInitSession(void);
void MpUtilMediaSvcFinishSession(void);

////////////////////////////////////////////////////////
// Manage video item list

// For gallery list
bool MpUtilMediaSvcExtractVideoListFromFolder(char* szFolderPath, int nSortType);    // For myfiles.
bool MpUtilMediaSvcExtractVideoListFromAllFolderOfGallery(int nSortType);            // For 'All' folder of gallery.
bool MpUtilMediaSvcExtractVideoListVideoType(int nSortType);                         // For only video type files of video list view.
bool MpUtilMediaSvcExtractVideoListRecordedType(int nSortType);                      // For only recorded type files of video list view.
bool MpUtilMediaSvcExtractVideoListByTagName(char *szTagName);                       // For tag folder of gallery.
bool MpUtilMediaSvcExtractVideoListFromFavorite(int nSortType);                      // For favorite naming of gallery.
bool MpUtilMediaSvcExtractVideoListForSearchView(const char *keyword);               // For only video type files of video search view*/


void MpUtilMediaSvcDestoryVideoList(void);
bool MpUtilMediaSvcRemoveItemByUrlWithList(char *szFilePath);
bool MpUtilMediaSvcRemoveItemByListIndex(int nVideoItemIndex);
bool MpUtilMediaSvcRemoveItemByListIndexWithoutListItem(int nVideoItemIndex);


bool MpUtilMediaSvcGetVideoIDByVideoUri(const char *szPath, char *szVideoID);
char* MpUtilMediaSvcGetVideoThumbnailByVideoUri(const char *szMediaUri);
unsigned int MpUtilMediaSvcGetVideoLastPlayTimeByVideoUri(const char *szPath);
unsigned int MpUtilMediaSvcGetVideoDurationByVideoUri(const char *szPath);
int MpUtilMediaSvcGetVideoFilesizeByVideoUri(const char *szPath);
void MpUtilMediaSvcSetVideoLastPlayedTimeByUri(char* szMediaUri, unsigned int nLastPlayedTime);

bool MpUtilMediaSvcGetVideoCurrentUrlPreNextItem(char* szCurrMediaUri, char* szPreMediaUri, char* szNextMediaUri,bool bLoop);

// For video list
char* MpUtilMediaSvcGetVideoUrl(const int nVideoItemIndex);
char* MpUtilMediaSvcGetVideoThumbnail(const int nVideoItemIndex);
char* MpUtilMediaSvcGetVideoTitle(const int nVideoItemIndex);
int MpUtilMediaSvcGetVideoDurationTime(const int nVideoItemIndex);
int MpUtilMediaSvcGetVideoLastPlayedPos(const int nVideoItemIndex);
int MpUtilMediaSvcGetVideoItemSize(const int nVideoItemIndex);
int MpUtilMediaSvcGetVideoItemWidth(const int nVideoItemIndex);
int MpUtilMediaSvcGetVideoItemHeight(const int nVideoItemIndex);
time_t MpUtilMediaSvcGetVideoItemDateTime(const int nVideoItemIndex);
char *MpUtilMediaSvcGetVideoItemExtension(const int nVideoItemIndex);
double MpUtilMediaSvcGetVideoItemLongitude(const int nVideoItemIndex);
double MpUtilMediaSvcGetVideoItemLatitude(const int nVideoItemIndex);

int MpUtilMediaSvcGetVideoListSizeForCheckingIndex(void);
int MpUtilMediaSvcGetNumberOfVideoItemByType(void);
int MpUtilMediaSvcGetTotalVideoTypeFiles(void);
void MpUtilMediaSvcPrintListInfo(void);
int MpUtilMediaSvcFindVideoItemIndexByUrl(const char *szPath);

// For folder list
bool MpUtilMediaSvcExtractVideoFolderList(int nSortType);
bool MpUtilMediaSvcDestoryVideoFolderList(void);
int MpUtilMediaSvcGetVideoFolderListSize(void);
char* MpUtilMediaSvcGetVideoFolderName(int nVideoFolderIndex);
char* MpUtilMediaSvcGetVideoFolderUrl(int nVideoFolderIndex);

////////////////////////////////////////////////////////
// Manage bookmark

bool MpUtilMediaSvcBookmarkListGet(char *vid, GList **list);
void MpUtilMediaSvcBookmarkListClear(GList *list);
int MpUtilMediaSvcBookmarkInsert(char *vid, int position, char *path);
int MpUtilMediaSvcBookmarkDelete(char *vid, int position);
int MpUtilMediaSvcBookmarkDeleteAll(char *vid);
char* MpUtilMediaSvcBookmarkGetThumbnail(void* pBookmarkItemHandle);
int MpUtilMediaSvcBookmarkGetPos(void* pBookmarkItemHandle);

#endif // _MP_UTIL_DATABASE_