/*
 * Copyright (c) [2012] Samsung Electronics Co., Ltd.
 *
 * Licensed under the Flora License, Version 1.1 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef _MP_VIDEO_PLAYER_MGR_H_
#define _MP_VIDEO_PLAYER_MGR_H_


#include <player.h>
#include <sound_manager.h>
#include <image_util.h>
#include <mm_util_imgp.h>


typedef enum
{
	DISPLAY_METHOD_LETTER_BOX		= 0,
	DISPLAY_METHOD_ORIGIN_SIZE,
	DISPLAY_METHOD_FULL_SCREEN,
	DISPLAY_METHOD_CROPPED_FULL,
	DISPLAY_METHOD_CUSTOM_ROI,
}MpPlayerMgrDisplayMethod;


typedef enum
{
	VIDEO_SCREEN_UNKNOWN			= 0,
	VIDEO_SCREEN_PORTRAIT,
	VIDEO_SCREEN_LANDSCAPE,
	VIDEO_SCREEN_PORTRAIT_UPSIDEDOWN,
	VIDEO_SCREEN_LANDSCAPE_UPSIDEDOWN,
}MpVideoRotation;


typedef enum
{
	SOUND_EFFECT_NORMAL				= 0,
	SOUND_EFFECT_VOICE,
	SOUND_EFFECT_MOVIE,
	SOUND_EFFECT_51CH,
	SOUND_EFFECT_MAX,
}MpSoundEffectType;


typedef enum
{
	FILE_STREAM_TYPE_NOTHING		= 0,
	FILE_STREAM_TYPE_VIDEO_AUDIO,
	FILE_STREAM_TYPE_AUDIO,
	FILE_STREAM_TYPE_VIDEO,
	FILE_STREAM_TYPE_MAX,
}MpFileStreamType;

bool	MpPlayerMgrIsActive(void);
bool	MpPlayerMgrRegistePlayerCallback(void *PlayerCompletedCbFunc, void *PlayerInterruptedCbFunc, void *PlayerErrorCbFunc, void *PlayerBufferingCbFunc, void *PlayerSubtitleCbFunc, void *pUserData);

bool	MpPlayerMgrCreate	(const char* szPath);
bool	MpPlayerMgrDestroy	(void);

bool	MpPlayerMgrRealize	(void);
bool	MpPlayerMgrRealizeAsync(void *pPrepareCb, void *pUserData);

bool	MpPlayerMgrUnrealize(void);

bool	MpPlayerMgrPlay		(void);
bool	MpPlayerMgrStop		(void);
bool	MpPlayerMgrResume	(void);
bool	MpPlayerMgrPause	(void);

int	MpPlayerMgrGetPosition(void);
void	MpPlayerMgrSetPosition(unsigned int nPos, void *pSeekCb, void *pUserData);
void 	MpPlayerMgrSetSubtitlePosition(unsigned int nPos);

void	MpPlayerMgrSetMute(bool bMuteEnable);
bool	MpPlayerMgrGetMute(void);

bool	MpPlayerMgrSetSurroundFilters(int nSurround);


int	MpPlayerMgrGetDuration(void);
bool	MpPlayerMgrSetOverlayXid(void* pOverlayXid);
bool 	MpPlayerMgrSetEvasSinkID(void *pEvasSinkID);

bool	MpPlayerMgrSetSoundPriority(void);
int	MpPlayerMgrSetPlaySpeed(float nSpeedValue);
int	MpPlayerMgrGetVideoWidthResolution(void);
int	MpPlayerMgrGetVideoHeightResolution(void);
bool	MpPlayerMgrSetSubtitle(char* szSubtitlePath);

int	MpPlayerMgrSetDisplayArea(int nX, int nY, int nWidth, int nHeight);
bool	MpPlayerMgrSetRotate(MpVideoRotation nRotation);
bool	MpPlayerMgrSetDisplayMode(MpPlayerMgrDisplayMethod nMethodMode);

bool	MpPlayerMgrSetUseragentForStreaming(const char* szUserAgent);
bool	MpPlayerMgrSetProxyAddressForStreaming(const char* szProxyAddress);
bool	MpPlayerMgrSetCookieForStreaming(const char* szCookie);

bool 	MpPlayerMgrStartCapture();
bool	MpPlayerMgrCaptureVideo(void *pCallbackFunc, void *pUserData);

int 	MpPlayerMgrGetBufferingPosition(void);
bool	MpPlayerMgrRegisteBufferingCallBack(void *pCallbackFunc, void *pUserData);
int	MpPlayerMgrGetFileStreamType(void);
bool 	MpPlayerMgrSetScaling(bool bScale);
void MpPlayerMgrSetVolume(float volume);
float MpPlayerMgrGetVolume(void);

player_state_e MpPlayerMgrGetPlayerState(void);

int MpPlayerMgrGetClosedCaptionCount(void);

#endif
