/*
 * Copyright (c) [2012] Samsung Electronics Co., Ltd.
 *
 * Licensed under the Flora License, Version 1.1 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __VIDEO_PLAYER__
#define	 __VIDEO_PLAYER__

#include <stdbool.h>
#include <utilX.h>
#include <Ecore_X.h>
#include <Elementary.h>


#include "mp-video-value-define.h"
#include "mp-video-type-define.h"

#define LVL0 (0)
#define LVL1 (1)
#define LVL2 (2)
#define LVL3 (3)
#define LVL4 (4)
#define LVL5 (5)
#define LVL6 (6)
#define LVL7 (7)

typedef enum
{
	MP_UG_FAIL,
	MP_UG_SUCCESS
} mp_ug_load_status;

typedef struct _VideoAppData		VideoAppData;


typedef struct
{
	void (*VideoAppCtrlStart)			(VideoAppData* pAppData);
	void (*VideoAppCtrlStop)			(VideoAppData* pAppData);
	void (*VideoAppCtrlPause)			(VideoAppData* pAppData);
	void (*VideoAppCtrlResume)			(VideoAppData* pAppData);
	void (*VideoAppCtrlStopByAppPause)		(VideoAppData* pAppData);
	void (*VideoAppCtrlStartByAppResume)		(VideoAppData* pAppData);
	void (*VideoAppCtrlFFDown)			(VideoAppData* pAppData);
	void (*VideoAppCtrlRewDown)			(VideoAppData* pAppData);
	void (*VideoAppCtrlFFUp)			(VideoAppData* pAppData);
	void (*VideoAppCtrlRewUp)			(VideoAppData* pAppData);
	void (*VideoAppCtrlSpeedReset)			(VideoAppData* pAppData);
	void (*VideoAppCtrlSpeedFF)			(VideoAppData* pAppData);
	void (*VideoAppCtrlSpeedRew)			(VideoAppData* pAppData);
	void (*VideoAppCtrlRotateScreen)		(VideoAppData *pAppData, int nRotateState);
	void (*VideoAppCtrlGetPosition)			(VideoAppData* pAppData);
	void (*VideoAppCtrlSetPosition)			(VideoAppData* pAppData);
	void (*VideoAppCtrlSetSubtitlePosition)		(VideoAppData* pAppData);
	void (*VideoAppCtrlHideLayout)			(VideoAppData* pAppData);
	void (*VideoAppCtrlShowLayout)			(VideoAppData* pAppData);
	void (*VideoAppCtrlHideFinish)			(VideoAppData* pAppData);
	void (*VideoAppCtrlShowFinish)			(VideoAppData* pAppData);
	void (*VideoAppCtrlGetVideoResolution)		(VideoAppData* pAppData);
	void (*VideoAppCtrlReqDurationTime)		(VideoAppData* pAppData);
	void (*VideoAppCtrlChangeResolution)		(VideoAppData* pAppData);
	void (*VideoAppCtrlBeginOfStream)		(VideoAppData* pAppData);
	void (*VideoAppCtrlEndOfStream)			(VideoAppData* pAppData);
	void (*VideoAppCtrlExit)			(VideoAppData* pAppData);
	void (*VideoAppCtrlStartStreaming)		(VideoAppData* pAppData);
	void (*VideoAppCtrlReLaunching)			(VideoAppData* pAppData);
	void (*VideoAppCtrlGetBufferingPosition)	(VideoAppData* pAppData);
	void (*VideoAppCtrlSetMute)			(VideoAppData *pAppData, bool bMute);


	void (*VideoAppCtrlShowVolume)			(VideoAppData *pAppData);
	void (*VideoAppCtrlHideVolume)			(VideoAppData *pAppData);
}VideoAppCtrlFunc;


struct _VideoAppData
{
	Evas_Object*		pMainWindow;

	int			nDuration;
	int			nSetPosition;
	int			nCurPosition;
	int			nSubtitleDuration;
	int			nBufferingPosition;
	int			nPlayingSpeed;

	int			nVideoWidthResolution;
	int			nVideoHeightResolution;

	char			*szSubtitle;
	char			*szVideoTitle;
	char			*szMediaUri;
	char			*szPreMediaUri;
	char			*szNextMediaUri;

	MpPlayerState       nPrePlayerState;
	MpPlayerState       nCurPlayerState;
	VideoAppCtrlFunc    VideoAppCtrlCallbackFunc;
	bool				bSeekComplete;
	int					nSeekPosition;
	MpPlayerState       nSeekPlayerState;

	char			*szProxyAddress;
	char			*szUserAgent;
	char			*szCookie;

	bool			bStartSeek;
};

#endif //__VIDEO_PLAYER__
