/*
 * Copyright (c) [2012] Samsung Electronics Co., Ltd.
 *
 * Licensed under the Flora License, Version 1.1 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */




#include <media_content.h>


#include "mp-video-log.h"
#include "mp-video-value-define.h"
#include "mp-video-type-define.h"
#include "mp-util-media-service.h"
#include "mp-video-string-define.h"



static Eina_List *VideoFolderList = NULL;
static Eina_List *VideoItemList = NULL;
static int nWhatFileType = MP_MEDIA_VIDEO_FILE_TYPE;
static int nTotalVideoTypeFiles = 0;
static int nNumberOfVideoItemByType = 0;


bool MpUtilMediaSvcIs3gpFile(char* szFileUri)
{
	VideoLogInfo("");

	int nRet = FALSE;
	char* szTmpUriPath = szFileUri;

	if(szTmpUriPath)
	{
		char *szExt = NULL;
		szExt = strrchr(szTmpUriPath, '.');

		if((szExt != NULL) && ((szExt+1) != NULL))
		{
			if(!strcmp(szExt+1, "3gp"))
			{
				nRet = TRUE;
			}
			else
			{
				nRet = FALSE;
			}
		}
		else
		{
			VideoLogInfo("No exist extension.");
			nRet = FALSE;
		}
	}
	else
	{
		VideoLogInfo("No exist file uri.");
		nRet = FALSE;
	}

	return nRet;
}

static bool MpUtilMediaSvcIterateForGetVideoItemCb(media_info_h pVideoItem, void *pUserData)
{
	VideoLogInfo("");

	media_info_h *pAssignFolderItem = (media_info_h*)pUserData;

	if(pVideoItem != NULL)
	{
		char *szTmpStr = NULL;
		media_info_clone(pAssignFolderItem, pVideoItem);
		media_info_get_display_name(*pAssignFolderItem, &szTmpStr);
		VideoLogInfo("Display name : %s", szTmpStr);

		if(szTmpStr)
		{
			free(szTmpStr);
		}
	}

	return FALSE;
}

static bool MpUtilMediaSvcIterateForVideoItemListViewCb(media_info_h pMediaItem, void *pUserData)
{
	VideoLogInfo("");

	media_info_h pAssignMediaItem = NULL;
	media_content_type_e nMediaType = MEDIA_CONTENT_TYPE_OTHERS;

	media_info_get_media_type(pMediaItem, &nMediaType);
	VideoLogInfo("nMediaType : %d", nMediaType);

	if(nMediaType == MEDIA_CONTENT_TYPE_VIDEO)
	{
		char *szTmpItemFilePath = NULL;
		char szItemFilePath[STR_LEN_MAX] = {0};

		media_info_get_file_path(pMediaItem, &szTmpItemFilePath);

		if(szTmpItemFilePath == NULL)
		{
			VideoLogInfo("Fail to get file path of media item.");
			return FALSE;
		}
		strncpy(szItemFilePath, szTmpItemFilePath, STR_LEN_MAX - 1);

		free(szTmpItemFilePath);
		szTmpItemFilePath = NULL;

		VideoLogInfo("szItemFilePath : %s", szItemFilePath);

		nTotalVideoTypeFiles++;

		switch(nWhatFileType)
		{
		case MP_MEDIA_VIDEO_FILE_TYPE:
			if(MpUtilMediaSvcIs3gpFile(szItemFilePath) == TRUE)
			{
				return TRUE;
			}
			break;

		case MP_MEDIA_CAMERA_FILE_TYPE:
			if(MpUtilMediaSvcIs3gpFile(szItemFilePath) == FALSE)
			{
				return TRUE;
			}
			break;

		case MP_MEDIA_ALL_FILE_TYPE:
			break;
		}

		nNumberOfVideoItemByType++;
		VideoLogInfo("nNumberOfVideoItemByType : %d", nNumberOfVideoItemByType);

		media_info_clone(&pAssignMediaItem, pMediaItem);
		Eina_List **pList = (Eina_List **)pUserData;
		*pList = eina_list_append(*pList, pAssignMediaItem);
	}

	return TRUE;
}

static bool MpUtilMediaSvcIterateCb(media_info_h pMediaItem, void *pUserData)
{
	VideoLogInfo("");

	media_info_h pAssignMediaItem = NULL;
	media_content_type_e nMediaType = MEDIA_CONTENT_TYPE_OTHERS;

	media_info_get_media_type(pMediaItem, &nMediaType);
	VideoLogInfo("nMediaType : %d", nMediaType);

	if(nMediaType == MEDIA_CONTENT_TYPE_VIDEO)
	{
		media_info_clone(&pAssignMediaItem, pMediaItem);
		Eina_List **pList = (Eina_List **)pUserData;
		*pList = eina_list_append(*pList, pAssignMediaItem);

		nTotalVideoTypeFiles++;
		nNumberOfVideoItemByType++;
		VideoLogInfo("nNumberOfVideoItemByType : %d", nNumberOfVideoItemByType);
	}

	return TRUE;
}

static bool MpUtilMediaSvcIterateForGetFolderCb(media_folder_h pFolderItem, void *pUserData)
{
	VideoLogInfo("");

	media_folder_h *pAssignFolderItem = (media_folder_h*)pUserData;

	if(pFolderItem != NULL)
	{
		char *szTmpStr = NULL;
		media_folder_clone(pAssignFolderItem, pFolderItem);
		media_folder_get_name(*pAssignFolderItem, &szTmpStr);
		VideoLogInfo("Folder name : %s", szTmpStr);

		if(szTmpStr)
		{
			free(szTmpStr);
		}
	}

	return FALSE;
}

static bool MpUtilMediaSvcIterateForFolderListCb(media_folder_h pFolderItem, void *pUserData)
{
	VideoLogInfo("");

	media_folder_h pAssignFolderItem = NULL;
	media_folder_clone(&pAssignFolderItem, pFolderItem);
	Eina_List **pList = (Eina_List **)pUserData;
	*pList = eina_list_append(*pList, pAssignFolderItem);

	return TRUE;
}

static bool MpUtilMediaSvcIterateGetTagCb(media_tag_h pTagItem, void *pUserData)
{
	VideoLogInfo("");

	media_tag_h *pAssignTagItem = (media_tag_h*)pUserData;

	if(!pTagItem)
	{
		char *szTmpStr = NULL;
		media_tag_clone(pAssignTagItem, pTagItem);
		media_tag_get_name(*pAssignTagItem, &szTmpStr);
		VideoLogInfo("szTagName : %s", szTmpStr);

		if(szTmpStr)
		{
			free(szTmpStr);
		}
	}

	return FALSE;
}

static bool MpUtilMediaSvcIterateGetVideoItemOfTagCb(media_info_h media, void *pUserData)
{
	VideoLogInfo("");

	return TRUE;
}

//
// Internal function
//
bool MpUtilMediaSvcGetFileDirectoryName(char *szFilePath, char *szFileName, char *szDirectoryName, char *szDirectoryPath)
{
	VideoLogInfo("");

	if(!szFilePath)
	{
		VideoLogInfo("[ERR]");
		return FALSE;
	}

	int nCount = 0;
	int nLoopCount = 0;

	for(nLoopCount = strlen(szFilePath); nLoopCount >= 0; nLoopCount--)
	{
		if (szFilePath[nLoopCount] != '\0')
		{
			nCount++;
		}

		if(szFilePath[nLoopCount] == '/')
		{
			if(szFileName)
			{
				memcpy(szFileName, &szFilePath[nLoopCount + 1], --nCount);
				*(szFileName + nCount) = '\0';
				VideoLogInfo("File name = %s\n", szFileName);
			}

			if(szDirectoryPath)
			{
				memcpy(szDirectoryPath, &szFilePath[0], nLoopCount);
				*(szDirectoryPath + nLoopCount + 1) = '\0';
				VideoLogInfo("Directory path = %s", szDirectoryPath);
			}

			if(szDirectoryName)
			{
				nCount = 0;
				for(--nLoopCount; nLoopCount >= 0; nLoopCount--)
				{
					nCount++;
					if(szFilePath[nLoopCount] == '/')
					{
						memcpy(szDirectoryName, &szFilePath[nLoopCount + 1], --nCount);
						*(szDirectoryName + nCount) = '\0';
						VideoLogInfo("Directory Name = %s", szDirectoryName);

						return TRUE;
					}
				}
			}

			return TRUE;
		}
	}

	return FALSE;
}

//
// External function
//

void MpUtilMediaSvcInitSession(void)
{
	VideoLogInfo("");

	if(media_content_connect() != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to connect to media content db.");
	}
	else
	{
		VideoLogInfo("Success to connect to media content db.");
	}
}

void MpUtilMediaSvcFinishSession(void)
{
	VideoLogInfo("");

	if(media_content_disconnect() != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to disconnect from media content db.");
		return;
	}


	VideoLogInfo("Success to disconnect from media content db.");
	return;
}

bool MpUtilMediaSvcDestoryVideoItemList(void)
{
	if(!VideoItemList)
	{
		VideoLogInfo("VideoItemList is empty already.");
		return FALSE;
	}

	media_info_h pTmpVideoItem = NULL;
	EINA_LIST_FREE(VideoItemList, pTmpVideoItem)
	{
		if(pTmpVideoItem)
		{
			media_info_destroy(pTmpVideoItem);
		}
	}

	VideoItemList = NULL;

	return TRUE;
}

bool MpUtilMediaSvcExtractVideoListFromFolder(char *szFolderPath, int nSortType)
{
	if(VideoItemList)
	{
		VideoLogInfo("Already exist video list.");
		return FALSE;
	}

	if(!szFolderPath)
	{
		VideoLogInfo("[ERR]");
		return FALSE;
	}

	VideoLogInfo("");

	filter_h m_FilterHandle = NULL;
	media_folder_h m_FolderHandle = NULL;
	media_content_order_e nOrderType = MEDIA_CONTENT_ORDER_ASC;

	char *szFolderID = NULL;
	char szTmpStr[STR_LEN_MAX] = {0};
	char szOrderObj[STR_LEN_MAX] = {0};

	nTotalVideoTypeFiles = 0;
	nNumberOfVideoItemByType = 0;

	switch(nSortType)
	{
	case MP_MEDIA_SORT_BY_NONE:
	case MP_MEDIA_SORT_BY_NAME_ASC:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_NAME_DESC:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_DATE_MOST_RECENT:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_YEAR, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_OLDEST:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_YEAR, STR_LEN_MAX - 1);
		break;

	default:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
	}

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_TYPE = 1 and FOLDER_PATH = \"%s\"", szFolderPath);
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_folder_foreach_folder_from_db(m_FilterHandle, MpUtilMediaSvcIterateForGetFolderCb, &m_FolderHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail media_folder_foreach_folder_from_db().");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(!m_FolderHandle)
	{
		VideoLogInfo("Fail to get folder handle.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_TYPE = 1");
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_set_order(m_FilterHandle, nOrderType, szOrderObj, MEDIA_CONTENT_COLLATE_NOCASE) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set order.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_folder_get_folder_id(m_FolderHandle, &szFolderID) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get folder id.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_folder_foreach_media_from_db(szFolderID, m_FilterHandle, MpUtilMediaSvcIterateCb, &VideoItemList) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set order.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
	}

	if(szFolderID)
	{
		free(szFolderID);
		szFolderID = NULL;
	}

	return TRUE;
}

bool MpUtilMediaSvcExtractVideoListFromAllFolderOfGallery(int nSortType)
{
	if(VideoItemList)
	{
		VideoLogInfo("Already exist video list.");
		return FALSE;
	}

	VideoLogInfo("");

	filter_h m_FilterHandle = NULL;
	media_content_order_e nOrderType = MEDIA_CONTENT_ORDER_ASC;
	char szOrderObj[STR_LEN_MAX] = {0};

	nTotalVideoTypeFiles = 0;
	nNumberOfVideoItemByType = 0;

	switch(nSortType)
	{
	case MP_MEDIA_SORT_BY_NONE:
	case MP_MEDIA_SORT_BY_NAME_ASC:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_NAME_DESC:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_DATE_MOST_RECENT:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_YEAR, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_OLDEST:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_YEAR, STR_LEN_MAX - 1);
		break;

	default:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
	}

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	if(media_filter_set_condition(m_FilterHandle, MEDIA_TYPE" = 1", MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_set_order(m_FilterHandle, nOrderType, szOrderObj, MEDIA_CONTENT_COLLATE_NOCASE) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set order.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateCb, &VideoItemList) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return FALSE;
	}

	return TRUE;
}

bool MpUtilMediaSvcExtractVideoListForListView(int nSortType)
{
	if(VideoItemList)
	{
		VideoLogInfo("Already exist video list.");
		return FALSE;
	}

	VideoLogInfo("");

	filter_h m_FilterHandle = NULL;
	media_content_order_e nOrderType = MEDIA_CONTENT_ORDER_ASC;
	char szOrderObj[STR_LEN_MAX] = {0};

	nTotalVideoTypeFiles = 0;
	nNumberOfVideoItemByType = 0;

	switch(nSortType)
	{
	case MP_MEDIA_SORT_BY_NONE:
	case MP_MEDIA_SORT_BY_NAME_ASC:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_NAME_DESC:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_DATE_MOST_RECENT:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_MODIFIED_TIME, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_OLDEST:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_MODIFIED_TIME, STR_LEN_MAX - 1);
		break;

	default:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
	}

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	if(media_filter_set_condition(m_FilterHandle, MEDIA_TYPE" = 1", MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_set_order(m_FilterHandle, nOrderType, szOrderObj, MEDIA_CONTENT_COLLATE_NOCASE) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set order.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateForVideoItemListViewCb, &VideoItemList) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return FALSE;
	}

	return TRUE;
}

bool MpUtilMediaSvcExtractVideoListVideoType(int nSortType)
{
	VideoLogInfo("");

	nWhatFileType = MP_MEDIA_VIDEO_FILE_TYPE;

	return MpUtilMediaSvcExtractVideoListForListView(nSortType);
}

bool MpUtilMediaSvcExtractVideoListRecordedType(int nSortType)
{
	VideoLogInfo("");

	nWhatFileType = MP_MEDIA_CAMERA_FILE_TYPE;

	return MpUtilMediaSvcExtractVideoListForListView(nSortType);
}

bool MpUtilMediaSvcExtractVideoListByTagName(char *szTagName)
{
	VideoLogInfo("");

	if(!szTagName)
	{
		VideoLogInfo("[ERR] No Exist tag name.");
		return FALSE;
	}

	if(VideoItemList)
	{
		VideoLogInfo("Already exist video list.");
		return FALSE;
	}

	VideoLogInfo("szTagName : %s", szTagName);

	int nTagID = 0;
	char szTmpStr[STR_LEN_MAX] = {0};

	media_tag_h pTagHandle = NULL;
	filter_h m_FilterHandle = NULL;

	nTotalVideoTypeFiles = 0;
	nNumberOfVideoItemByType = 0;

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	//snprintf(szTmpStr, STR_LEN_MAX-1, "TAG_NAME like \"%s\"", szTagName);//snprintf(szTmpStr, STR_LEN_MAX-1, "TAG_NAME like \"\%%s\%\"", szTagName);
	snprintf(szTmpStr, STR_LEN_MAX-1, "TAG_NAME like \"%%%s%%\"", szTagName);
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		if(m_FilterHandle)
		{
			media_filter_destroy(m_FilterHandle);
			m_FilterHandle = NULL;
		}
		return FALSE;
	}

	if(media_filter_set_order(m_FilterHandle, MEDIA_CONTENT_ORDER_ASC, TAG_NAME, MEDIA_CONTENT_COLLATE_NOCASE) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set order.");
		if(m_FilterHandle)
		{
			media_filter_destroy(m_FilterHandle);
			m_FilterHandle = NULL;
		}
		return FALSE;
	}

	if(media_tag_foreach_tag_from_db(m_FilterHandle, MpUtilMediaSvcIterateGetTagCb, &pTagHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail media_tag_foreach_tag_from_db().");
		if(m_FilterHandle)
		{
			media_filter_destroy(m_FilterHandle);
			m_FilterHandle = NULL;
		}
		return FALSE;
	}

	if(!pTagHandle)
	{
		VideoLogInfo("Fail to get pTagHandle.");
		if(m_FilterHandle)
		{
			media_filter_destroy(m_FilterHandle);
			m_FilterHandle = NULL;
		}
		return FALSE;
	}

	if(media_tag_get_tag_id(pTagHandle, &nTagID) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get tag ID.");
		if(m_FilterHandle)
		{
			media_filter_destroy(m_FilterHandle);
			m_FilterHandle = NULL;
		}
		return FALSE;
	}

	VideoLogInfo("nTagID : %d", nTagID);

	memset(szTmpStr, 0, STR_LEN_MAX);
	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_TYPE = 1");
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		if(m_FilterHandle)
		{
			media_filter_destroy(m_FilterHandle);
			m_FilterHandle = NULL;
		}
		return FALSE;
	}

	if(media_filter_set_order(m_FilterHandle, MEDIA_CONTENT_ORDER_ASC, MEDIA_TITLE, MEDIA_CONTENT_COLLATE_NOCASE) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set order.");
		if(m_FilterHandle)
		{
			media_filter_destroy(m_FilterHandle);
			m_FilterHandle = NULL;
		}
		return FALSE;
	}

	if(media_tag_foreach_media_from_db(nTagID, m_FilterHandle, MpUtilMediaSvcIterateGetVideoItemOfTagCb, VideoItemList) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail media_tag_foreach_media_from_db().");
		if(m_FilterHandle)
		{
			media_filter_destroy(m_FilterHandle);
			m_FilterHandle = NULL;
		}
		return FALSE;
	}
	if(m_FilterHandle)
	{
		if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
		{
			VideoLogInfo("Fail to destroy media filter handle.");
			return FALSE;
		}
		m_FilterHandle = NULL;
	}

	return TRUE;
}

bool MpUtilMediaSvcExtractVideoListFromFavorite(int nSortType)
{
	if(VideoItemList)
	{
		VideoLogInfo("Already exist video list.");
		return FALSE;
	}

	VideoLogInfo("");

	filter_h m_FilterHandle = NULL;
	media_content_order_e nOrderType = MEDIA_CONTENT_ORDER_ASC;
	char szOrderObj[STR_LEN_MAX] = {0};
	char szTmpStr[STR_LEN_MAX] = {0};

	nWhatFileType = MP_MEDIA_ALL_FILE_TYPE;

	nTotalVideoTypeFiles = 0;
	nNumberOfVideoItemByType = 0;

	switch(nSortType)
	{
	case MP_MEDIA_SORT_BY_NONE:
	case MP_MEDIA_SORT_BY_NAME_ASC:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_NAME_DESC:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_DATE_MOST_RECENT:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_YEAR, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_OLDEST:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_YEAR, STR_LEN_MAX - 1);
		break;

	default:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
	}

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_TYPE = 1 and MEDIA_FAVOURITE = 1");
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_set_order(m_FilterHandle, nOrderType, szOrderObj, MEDIA_CONTENT_COLLATE_NOCASE) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set order.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateForVideoItemListViewCb, &VideoItemList) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return FALSE;
	}

	return TRUE;
}

bool MpUtilMediaSvcExtractVideoListForSearchView(const char *keyword)
{
	if(VideoItemList)
	{
		VideoLogInfo("Already exist video list.");
		return FALSE;
	}

	VideoLogInfo("");

	filter_h m_FilterHandle = NULL;
	media_content_order_e nOrderType = MEDIA_CONTENT_ORDER_ASC;
	char szOrderObj[STR_LEN_MAX] = {0};
	char szTmpStr[STR_LEN_MAX] = {0};

	nWhatFileType = MP_MEDIA_ALL_FILE_TYPE;

	nTotalVideoTypeFiles = 0;
	nNumberOfVideoItemByType = 0;

	nOrderType = MEDIA_CONTENT_ORDER_ASC;
	strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_TYPE = 1 and MEDIA_TITLE like \"%%%s%%\"", keyword);
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_set_order(m_FilterHandle, nOrderType, szOrderObj, MEDIA_CONTENT_COLLATE_NOCASE) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set order.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateForVideoItemListViewCb, &VideoItemList) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return FALSE;
	}

	return TRUE;
}


void MpUtilMediaSvcDestoryVideoList(void)
{
	VideoLogInfo("");

	if(VideoFolderList)
	{
		MpUtilMediaSvcDestoryVideoFolderList();
		VideoFolderList = NULL;
	}

	if(VideoItemList)
	{
		MpUtilMediaSvcDestoryVideoItemList();
		VideoItemList = NULL;
	}

	nTotalVideoTypeFiles = 0;
	nNumberOfVideoItemByType = 0;
}

bool MpUtilMediaSvcRemoveItemByUrlWithList(char *szFilePath)
{
	if(!szFilePath)
	{
		VideoLogInfo("[ERR]");
		return FALSE;
	}

	if(!VideoItemList)
	{
		VideoLogInfo("pList is empty already.");
		return FALSE;
	}

	VideoLogInfo("szFilePath : %s", szFilePath);

	char *szGetFilePath = NULL;
	media_info_h pItem = NULL;
	Eina_List *pIterateList = NULL;
	EINA_LIST_FOREACH(VideoItemList, pIterateList, pItem)
	{
		if(pItem)
		{
			if(media_info_get_file_path(pItem, &szGetFilePath) == MEDIA_CONTENT_ERROR_NONE)
			{
				if(szGetFilePath)
				{
					if(!strcmp(szGetFilePath, szFilePath))
					{
						VideoLogInfo("Find %s", szGetFilePath);
						char *szMediaID = NULL;
						media_info_get_media_id(pItem, &szMediaID);
						media_info_delete_from_db(szMediaID);
						VideoItemList = eina_list_remove(VideoItemList, pItem);
						media_info_destroy(pItem);

						nNumberOfVideoItemByType--;
						VideoLogInfo("nNumberOfVideoItemByType : %d", nNumberOfVideoItemByType);

						if(szMediaID)
						{
							free(szMediaID);
						}

						if(szGetFilePath)
						{
							free(szGetFilePath);
						}

						return TRUE;
					}
				}
				else
				{
					VideoLogInfo("No exist %s in media info Database module.", szFilePath);
					return FALSE;
				}
			}
		}
	}
	return FALSE;
}

bool MpUtilMediaSvcRemoveItemByListIndex(int nVideoItemIndex)
{
	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	if(!VideoItemList)
	{
		VideoLogInfo("pList is empty already.");
		return FALSE;
	}

	media_info_h pItem = eina_list_nth(VideoItemList, nVideoItemIndex);

	if(pItem)
	{
		char *szMediaID = NULL;
		media_info_get_media_id(pItem, &szMediaID);
		if(szMediaID)
		{
			media_info_delete_from_db(szMediaID);
			VideoItemList = eina_list_remove(VideoItemList, pItem);
			free(szMediaID);
			media_info_destroy(pItem);
			nNumberOfVideoItemByType--;
			VideoLogInfo("nNumberOfVideoItemByType : %d", nNumberOfVideoItemByType);
		}
		else
		{
			VideoLogInfo("No exist media ID in index %d of list.", nVideoItemIndex);
			return FALSE;
		}
	}
	else
	{
		VideoLogInfo("Fail to remove item in media svc and list.");
		return FALSE;
	}

	return TRUE;
}

bool MpUtilMediaSvcRemoveItemByListIndexWithoutListItem(int nVideoItemIndex)
{
	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	if(!VideoItemList)
	{
		VideoLogInfo("pList is empty already.");
		return FALSE;
	}

	media_info_h pItem = eina_list_nth(VideoItemList, nVideoItemIndex);

	if(pItem)
	{
		char *szMediaID = NULL;
		media_info_get_media_id(pItem, &szMediaID);
		if(szMediaID)
		{
			media_info_delete_from_db(szMediaID);
			free(szMediaID);
			nNumberOfVideoItemByType--;
			VideoLogInfo("nNumberOfVideoItemByType : %d", nNumberOfVideoItemByType);
		}
		else
		{
			VideoLogInfo("No exist media ID in index %d of list.", nVideoItemIndex);
			return FALSE;
		}
	}
	else
	{
		VideoLogInfo("Fail to remove item in media svc and list.");
		return FALSE;
	}

	return TRUE;
}


bool MpUtilMediaSvcGetVideoIDByVideoUri(const char *szPath, char *szVideoID)
{
	VideoLogInfo("");

	media_info_h pVideoItem = NULL;
	filter_h m_FilterHandle = NULL;
	char szTmpStr[STR_LEN_MAX] = {0};
	bool bRet = FALSE;

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		bRet = FALSE;
	}

	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_PATH = \"%s\"", szPath);
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		bRet = FALSE;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateForGetVideoItemCb, &pVideoItem) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		bRet = FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		bRet = FALSE;
	}

	if(pVideoItem)
	{
		char *szMediaID = NULL;
		media_info_get_media_id(pVideoItem, &szMediaID);
		if(szMediaID)
		{
			strncpy(szVideoID, szMediaID, STR_LEN_MAX-2);
			free(szMediaID);
		}
		media_info_destroy(pVideoItem);
		bRet = TRUE;
	}
	else
	{
		bRet = FALSE;
	}

	return bRet;
}

unsigned int MpUtilMediaSvcGetVideoLastPlayTimeByVideoUri(const char *szPath)
{
	if(!szPath)
	{
		VideoLogInfo("No exist video path.");
		return 0;
	}

	VideoLogInfo("szPath : %s", szPath);

	time_t LastPlayedTime = 0;
	media_info_h pVideoItem = NULL;
	filter_h m_FilterHandle = NULL;
	char szTmpStr[STR_LEN_MAX] = {0};

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	//snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_PATH = \"%s\"", szPath);
	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_PATH = \"%s\"", szPath);
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateForGetVideoItemCb, &pVideoItem) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return FALSE;
	}

	if(pVideoItem)
	{
		video_meta_h pVideoMetaHandle = NULL;
		if(media_info_get_video(pVideoItem, &pVideoMetaHandle) == MEDIA_CONTENT_ERROR_NONE)
		{
			char *szTmpStr = NULL;
			video_meta_get_title(pVideoMetaHandle, &szTmpStr);
			if(szTmpStr)
			{
				VideoLogInfo("Title : %s", szTmpStr);
				free(szTmpStr);
			}
			else
			{
				VideoLogInfo("No exist title");
			}

			video_meta_get_played_time(pVideoMetaHandle, &LastPlayedTime);
			VideoLogInfo("Last Played Time : %d", LastPlayedTime);
			video_meta_destroy(pVideoMetaHandle);
		}
		media_info_destroy(pVideoItem);
	}

	return (unsigned int)LastPlayedTime;
}

unsigned int MpUtilMediaSvcGetVideoDurationByVideoUri(const char *szPath)
{
	if(!szPath)
	{
		VideoLogInfo("No exist video path.");
		return 0;
	}

	VideoLogInfo("szPath : %s", szPath);

	int nDurationTime = 0;
	media_info_h pVideoItem = NULL;
	filter_h m_FilterHandle = NULL;
	char szTmpStr[STR_LEN_MAX] = {0};

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_PATH = \"%s\"", szPath);
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateForGetVideoItemCb, &pVideoItem) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return FALSE;
	}

	if(pVideoItem)
	{
		video_meta_h pVideoMetaHandle = NULL;
		if(media_info_get_video(pVideoItem, &pVideoMetaHandle) == MEDIA_CONTENT_ERROR_NONE)
		{
			video_meta_get_duration(pVideoMetaHandle, &nDurationTime);
			VideoLogInfo("Duration time : %d", nDurationTime);
			video_meta_destroy(pVideoMetaHandle);
		}
		media_info_destroy(pVideoItem);
	}

	return (unsigned int)nDurationTime;
}

int MpUtilMediaSvcGetVideoFilesizeByVideoUri(const char *szPath)
{
	if(!szPath)
	{
		VideoLogInfo("No exist video path.");
		return 0;
	}

	VideoLogInfo("szPath : %s", szPath);

	unsigned long long nSize = 0;
	media_info_h pVideoItem = NULL;
	filter_h m_FilterHandle = NULL;
	char szTmpStr[STR_LEN_MAX] = {0};

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_PATH = \"%s\"", szPath);
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateForGetVideoItemCb, &pVideoItem) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return FALSE;
	}

	if(pVideoItem)
	{
		media_info_get_size(pVideoItem, &nSize);
		VideoLogInfo("Video file size time : %d", nSize);
		media_info_destroy(pVideoItem);
	}

	return nSize;
}

char *MpUtilMediaSvcGetVideoThumbnailByVideoUri(const char *szMediaUri)
{
	if(!szMediaUri)
	{
		VideoLogInfo("No exist video path.");
		return NULL;
	}

	VideoLogInfo("szPath : %s", szMediaUri);

	media_info_h pVideoItem = NULL;
	filter_h m_FilterHandle = NULL;
	char *szThumbnailPath = NULL;
	char szTmpStr[STR_LEN_MAX] = {0};

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	memset(szTmpStr, 0, STR_LEN_MAX);
	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_PATH = \"%s\"", szMediaUri);
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateForGetVideoItemCb, &pVideoItem) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return FALSE;
	}

	if(pVideoItem)
	{
		media_info_get_thumbnail_path(pVideoItem, &szThumbnailPath);
		VideoLogInfo("Video thumbnail file path : %s", szThumbnailPath);
		media_info_destroy(pVideoItem);
	}

	return szThumbnailPath;
}

void MpUtilMediaSvcSetVideoLastPlayedTimeByUri(char* szMediaUri, unsigned int nLastPlayedTime)
{
	if(!szMediaUri)
	{
		VideoLogInfo("No exist media uri.");
		return;
	}

	VideoLogInfo("szMediaUri : %s, nLastPlayedTime : %d", szMediaUri, nLastPlayedTime);

	time_t LastPlayedTime = (time_t)nLastPlayedTime;
	media_info_h pVideoItem = NULL;
	filter_h m_FilterHandle = NULL;
	char szTmpStr[STR_LEN_MAX] = {0};

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return;
	}

	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_PATH = \"%s\"", szMediaUri);
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return;
	}

	if(media_info_foreach_media_from_db(m_FilterHandle, MpUtilMediaSvcIterateForGetVideoItemCb, &pVideoItem) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get video item list with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return;
	}

	video_meta_h pVideoMetaHandle = NULL;

	if(pVideoItem)
	{
		if(media_info_get_video(pVideoItem, &pVideoMetaHandle) != MEDIA_CONTENT_ERROR_NONE)
		{
			VideoLogInfo("Fail to get pVideoMetaHandle.");
		}
		else
		{
			if(pVideoMetaHandle)
			{
				char *szTmpStr = NULL;
				video_meta_get_title(pVideoMetaHandle, &szTmpStr);
				if(szTmpStr)
				{
					VideoLogInfo("Title : %s", szTmpStr);
					free(szTmpStr);
				}
				else
				{
					VideoLogInfo("No exist title");
				}

				video_meta_set_played_time(pVideoMetaHandle, LastPlayedTime);
				video_meta_update_to_db(pVideoMetaHandle);
				video_meta_destroy(pVideoMetaHandle);
				VideoLogInfo("Last Played Time : %d", LastPlayedTime);
			}
			else
			{
				VideoLogInfo("No exist pVideoMetaHandle");
			}
		}
		media_info_destroy(pVideoItem);
	}
}

bool MpUtilMediaSvcGetVideoCurrentUrlPreNextItem(char *szCurrMediaUri, char *szPreMediaUri, char *szNextMediaUri, bool bLoop)
{
	VideoLogInfo("");

	if(!szCurrMediaUri)
	{
		VideoLogInfo("[ERR] No exist current file path.");
		return FALSE;
	}

	if(!VideoItemList)
	{
		VideoLogInfo("No exist VideoItemList.");
		if(bLoop)
		{
			strncpy(szNextMediaUri, szCurrMediaUri, (sizeof(char) * STR_LEN_MAX) - 1);
		}
		return FALSE;
	}

	int nCount = 0;
	int nListSize = 0;
	media_info_h pVideoItem = NULL;
	Eina_List *pIterateList = NULL;

	memset(szPreMediaUri, 0, sizeof(char) * STR_LEN_MAX);
	memset(szNextMediaUri, 0, sizeof(char) * STR_LEN_MAX);

	nListSize = eina_list_count(VideoItemList);

	if(nListSize <= 1)
	{
		VideoLogInfo("Video list size == 1.");
		return FALSE;
	}

	EINA_LIST_FOREACH(VideoItemList, pIterateList, pVideoItem)
	{
		if(pVideoItem == NULL)
		{
			continue;
		}

		char *szVideoItemFilePath = NULL;
		media_info_get_file_path(pVideoItem, &szVideoItemFilePath);
		if(szVideoItemFilePath)
		{
			VideoLogInfo("URL of the File item - %s (%d / %d)", szVideoItemFilePath, nCount, nListSize);
			if(!strcmp(szVideoItemFilePath, szCurrMediaUri))
			{
				free(szVideoItemFilePath);
				szVideoItemFilePath = NULL;

				pVideoItem = NULL;
				pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nCount - 1);
				if(pVideoItem)
				{
					media_info_get_file_path(pVideoItem, &szVideoItemFilePath);
					strncpy(szPreMediaUri, szVideoItemFilePath, (sizeof(char) * STR_LEN_MAX) - 1);

					free(szVideoItemFilePath);
					szVideoItemFilePath = NULL;
				}
				else if(bLoop)
				{
					media_info_h m_LastItem = (media_info_h)eina_list_nth(VideoItemList, nListSize - 1);
					VideoLogError("%p", m_LastItem);
					if(m_LastItem)
					{
						media_info_get_file_path(m_LastItem, &szVideoItemFilePath);
						strncpy(szPreMediaUri, szVideoItemFilePath, (sizeof(char) * STR_LEN_MAX) - 1);

						free(szVideoItemFilePath);
						szVideoItemFilePath = NULL;
					}
					m_LastItem = NULL;
				}

				pVideoItem = NULL;
				pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nCount + 1);
				if(pVideoItem)
				{
					media_info_get_file_path(pVideoItem, &szVideoItemFilePath);
					strncpy(szNextMediaUri, szVideoItemFilePath, (sizeof(char) * STR_LEN_MAX) - 1);

					free(szVideoItemFilePath);
					szVideoItemFilePath = NULL;
				}
				else if(bLoop)
				{
					media_info_h m_FirstItem = (media_info_h)eina_list_nth(VideoItemList, 0);
					if(m_FirstItem)
					{
						media_info_get_file_path(m_FirstItem, &szVideoItemFilePath);
						strncpy(szNextMediaUri, szVideoItemFilePath, (sizeof(char) * STR_LEN_MAX) - 1);

						free(szVideoItemFilePath);
						szVideoItemFilePath = NULL;
					}
					m_FirstItem = NULL;
				}

				VideoLogInfo("PreMediaUri:%s", szPreMediaUri);
				VideoLogInfo("NextMediaUri:%s", szNextMediaUri);

				return TRUE;
			}
		}

		++nCount;
	}

	return FALSE;
}

char* MpUtilMediaSvcGetVideoUrl(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	if(nVideoItemIndex < 0 || nVideoItemIndex >= MpUtilMediaSvcGetVideoListSizeForCheckingIndex())
	{
		VideoLogInfo("Error number of list item.");
		return NULL;
	}

	char *szVideoItemFilePath = NULL;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);

	if(pVideoItem)
	{
		media_info_get_file_path(pVideoItem, &szVideoItemFilePath);
		VideoLogInfo("szVideoItemFilePath : %s", szVideoItemFilePath);
	}

	return szVideoItemFilePath;
}

char* MpUtilMediaSvcGetVideoThumbnail(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	if(nVideoItemIndex < 0 || nVideoItemIndex >= MpUtilMediaSvcGetVideoListSizeForCheckingIndex())
	{
		VideoLogInfo("Error number of list item.");
		return NULL;
	}

	char *szVideoItemThumbnailPath = NULL;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);

	if(pVideoItem)
	{
		media_info_get_thumbnail_path(pVideoItem, &szVideoItemThumbnailPath);
		VideoLogInfo("szVideoItemFilePath : %s", szVideoItemThumbnailPath);
	}

	return szVideoItemThumbnailPath;
}

char* MpUtilMediaSvcGetVideoTitle(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	if(nVideoItemIndex < 0 || nVideoItemIndex >= MpUtilMediaSvcGetVideoListSizeForCheckingIndex())
	{
		VideoLogInfo("Error number of list item.");
		return NULL;
	}

	char *szTitle = NULL;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);

	if(pVideoItem)
	{
		media_info_get_display_name(pVideoItem, &szTitle);
		VideoLogInfo("szTitle : %s", szTitle);
	}

	return szTitle;
}

int MpUtilMediaSvcGetVideoDurationTime(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	if(nVideoItemIndex < 0 || nVideoItemIndex >= MpUtilMediaSvcGetVideoListSizeForCheckingIndex())
	{
		VideoLogInfo("Error number of list item.");
		return 0;
	}

	int nDurationTime = 0;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);

	if(pVideoItem)
	{
		video_meta_h pVideoMetaHandle = NULL;
		if(media_info_get_video(pVideoItem, &pVideoMetaHandle) == MEDIA_CONTENT_ERROR_NONE)
		{
			video_meta_get_duration(pVideoMetaHandle, &nDurationTime);
			VideoLogInfo("Duratiob time : %d", nDurationTime);
			video_meta_destroy(pVideoMetaHandle);
		}
	}

	return nDurationTime;
}

int MpUtilMediaSvcGetVideoLastPlayedPos(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	time_t nLastPlayedTime = 0;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);

	if(pVideoItem)
	{
		video_meta_h pVideoMetaHandle = NULL;
		if(media_info_get_video(pVideoItem, &pVideoMetaHandle) == MEDIA_CONTENT_ERROR_NONE)
		{
			video_meta_get_played_time(pVideoMetaHandle, &nLastPlayedTime);
			VideoLogInfo("Last Play time : %d", nLastPlayedTime);
			video_meta_destroy(pVideoMetaHandle);
		}
	}

	return (int)nLastPlayedTime;
}

int MpUtilMediaSvcGetVideoItemSize(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	unsigned long long nSize = 0;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);
	if(pVideoItem)
	{
		media_info_get_size(pVideoItem, &nSize);
		VideoLogInfo("Video file size time : %d", nSize);
	}

	return nSize;
}

int MpUtilMediaSvcGetVideoItemWidth(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	int nWidth = 0;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);
	video_meta_h pVideoMetaHandle = NULL;

	if(pVideoItem)
	{
		if(media_info_get_video(pVideoItem, &pVideoMetaHandle) != MEDIA_CONTENT_ERROR_NONE)
		{
			VideoLogInfo("Fail to get pVideoMetaHandle.");
		}
		else
		{
			if(pVideoMetaHandle)
			{
				char *szTmpStr = NULL;
				video_meta_get_title(pVideoMetaHandle, &szTmpStr);
				if(szTmpStr)
				{
					VideoLogInfo("Title : %s", szTmpStr);
					free(szTmpStr);
				}
				else
				{
					VideoLogInfo("No exist title");
				}

				video_meta_get_width(pVideoMetaHandle, &nWidth);
				video_meta_destroy(pVideoMetaHandle);
				VideoLogInfo("Video Width : %f", nWidth);
			}
			else
			{
				VideoLogInfo("No exist pVideoMetaHandle");
			}
		}
	}

	return nWidth;
}

int MpUtilMediaSvcGetVideoItemHeight(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	int nHeight = 0;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);
	video_meta_h pVideoMetaHandle = NULL;

	if(pVideoItem)
	{
		if(media_info_get_video(pVideoItem, &pVideoMetaHandle) != MEDIA_CONTENT_ERROR_NONE)
		{
			VideoLogInfo("Fail to get pVideoMetaHandle.");
		}
		else
		{
			if(pVideoMetaHandle)
			{
				char *szTmpStr = NULL;
				video_meta_get_title(pVideoMetaHandle, &szTmpStr);
				if(szTmpStr)
				{
					VideoLogInfo("Title : %s", szTmpStr);
					free(szTmpStr);
				}
				else
				{
					VideoLogInfo("No exist title");
				}

				video_meta_get_height(pVideoMetaHandle, &nHeight);
				video_meta_destroy(pVideoMetaHandle);
				VideoLogInfo("Video Width : %f", nHeight);
			}
			else
			{
				VideoLogInfo("No exist pVideoMetaHandle");
			}
		}
	}

	return nHeight;
}

time_t MpUtilMediaSvcGetVideoItemDateTime(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	time_t nDateTime = 0;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);
	if(pVideoItem)
	{
		media_info_get_modified_time(pVideoItem, &nDateTime);
		VideoLogInfo("Video date time : %d", nDateTime);
	}

	return nDateTime;
}

char *MpUtilMediaSvcGetVideoItemExtension(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	return NULL;
}

double MpUtilMediaSvcGetVideoItemLongitude(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	double nLongitude = 0;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);
	if(pVideoItem)
	{
		media_info_get_longitude(pVideoItem, &nLongitude);
		VideoLogInfo("nLongitude : %f", nLongitude);
	}

	return nLongitude;
}

double MpUtilMediaSvcGetVideoItemLatitude(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoItemIndex);

	double nLatitude = 0;
	media_info_h pVideoItem = (media_info_h)eina_list_nth(VideoItemList, nVideoItemIndex);
	if(pVideoItem)
	{
		media_info_get_latitude(pVideoItem, &nLatitude);
		VideoLogInfo("nLongitude : %f", nLatitude);
	}

	return nLatitude;
}




int MpUtilMediaSvcGetVideoListSizeForCheckingIndex(void)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("");

	return (int)eina_list_count(VideoItemList);
}

int MpUtilMediaSvcGetNumberOfVideoItemByType(void)
{
	VideoLogInfo("nNumberOfVideoItemByType : %d", nNumberOfVideoItemByType);

	return nNumberOfVideoItemByType;
}

int MpUtilMediaSvcGetTotalVideoTypeFiles(void)
{
	VideoLogInfo("nTotalVideoTypeFiles : %d", nTotalVideoTypeFiles);

	return (int)nTotalVideoTypeFiles;
}

void* MpUtilMediaSvcGetVideoitem(const int nVideoItemIndex)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return NULL;
	}

	if(nVideoItemIndex < 0 || nVideoItemIndex >= MpUtilMediaSvcGetVideoListSizeForCheckingIndex())
	{
		VideoLogInfo("Error number of list item.");
		return NULL;
	}

	VideoLogInfo("");

	return (void*)eina_list_nth(VideoItemList, nVideoItemIndex);
}

void MpUtilMediaSvcPrintListInfo(void)
{
	if(!VideoItemList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return;
	}

	VideoLogInfo("List size : %d", MpUtilMediaSvcGetNumberOfVideoItemByType());

	media_info_h pVideoItem = NULL;
	Eina_List *pIterateList = NULL;
	int nCounter = 0;
	EINA_LIST_FOREACH(VideoItemList, pIterateList, pVideoItem)
	{
		if(pVideoItem)
		{
			char *szTitle = NULL;
			media_info_get_display_name(pVideoItem, &szTitle);
			if(szTitle)
			{
				VideoLogInfo("%d - Print title of all list items : %s", nCounter, szTitle);
				free(szTitle);
			}
			else
			{
				VideoLogInfo("%d - Print title of all list items : NULL.", nCounter);
			}
			nCounter++;
		}
	}
}

int MpUtilMediaSvcFindVideoItemIndexByUrl(const char *szPath)
{
	if(!VideoItemList || !szPath)
	{
		VideoLogInfo("[ERR] No exist VideoItemList or szPath.");
		return 99999;
	}

	VideoLogInfo("");

	unsigned int nCounter = 0;

	Eina_List *pCurList = NULL;
	media_info_h pVideoItem = NULL;

	EINA_LIST_FOREACH(VideoItemList, pCurList, pVideoItem)
	{
		if(pVideoItem)
		{
			char *szTitle = NULL;
			media_info_get_display_name(pVideoItem, &szTitle);
			VideoLogInfo("szTitle : %s", szTitle);

			if(!strcmp(szTitle , szPath))
			{
				VideoLogInfo("Find same file url. index : %d", nCounter);
				free(szTitle);
				return nCounter;
			}
			free(szTitle);
		}

		nCounter++;
	}

	return 99999;
}

bool MpUtilMediaSvcExtractVideoFolderList(int nSortType)
{
	VideoLogInfo("");

	filter_h m_FilterHandle = NULL;
	media_content_order_e nOrderType = MEDIA_CONTENT_ORDER_ASC;

	char szTmpStr[STR_LEN_MAX] = {0};
	char szOrderObj[STR_LEN_MAX] = {0};

	switch(nSortType)
	{
	case MP_MEDIA_SORT_BY_NONE:
	case MP_MEDIA_SORT_BY_NAME_ASC:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_NAME_DESC:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_DATE_MOST_RECENT:
		nOrderType = MEDIA_CONTENT_ORDER_DESC;
		strncpy(szOrderObj, MEDIA_YEAR, STR_LEN_MAX - 1);
		break;

	case MP_MEDIA_SORT_BY_OLDEST:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_YEAR, STR_LEN_MAX - 1);
		break;

	default:
		nOrderType = MEDIA_CONTENT_ORDER_ASC;
		strncpy(szOrderObj, MEDIA_TITLE, STR_LEN_MAX - 1);
	}

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	snprintf(szTmpStr, STR_LEN_MAX, "MEDIA_TYPE = 1");
	if(media_filter_set_condition(m_FilterHandle, szTmpStr, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_folder_foreach_folder_from_db(m_FilterHandle, MpUtilMediaSvcIterateForFolderListCb, &VideoFolderList) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail media_folder_foreach_folder_from_db().");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
	}

	return TRUE;
}

bool MpUtilMediaSvcDestoryVideoFolderList(void)
{
	if(!VideoFolderList)
	{
		VideoLogInfo("VideoFolderList is empty already.");
		return FALSE;
	}

	media_folder_h pTmpFolderItem = NULL;
	EINA_LIST_FREE(VideoFolderList, pTmpFolderItem)
	{
		if(pTmpFolderItem)
		{
			media_folder_destroy(pTmpFolderItem);
		}
	}

	VideoFolderList = NULL;

	return TRUE;
}

int MpUtilMediaSvcGetVideoFolderListSize(void)
{
	if(!VideoFolderList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("");

	if(VideoFolderList)
	{
		return (int)eina_list_count(VideoFolderList);
	}

	return 0;
}

char* MpUtilMediaSvcGetVideoFolderName(int nVideoFolderIndex)
{
	if(!VideoFolderList)
	{
		VideoLogInfo("Not exist video folder list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoFolderIndex);

	if(nVideoFolderIndex < 0 || nVideoFolderIndex >= MpUtilMediaSvcGetVideoFolderListSize())
	{
		VideoLogInfo("Error number of list item.");
		return NULL;
	}

	char *szFolderName = NULL;
	media_folder_h pFolderItem = (media_folder_h)eina_list_nth(VideoFolderList, nVideoFolderIndex);
	if(pFolderItem)
	{
		media_folder_get_name(pFolderItem, &szFolderName);

		if(szFolderName)
		{
			VideoLogInfo("szFolderName : %s", szFolderName);
			return szFolderName;
		}
	}

	return NULL;
}

char* MpUtilMediaSvcGetVideoFolderUrl(int nVideoFolderIndex)
{
	if(!VideoFolderList)
	{
		VideoLogInfo("Not exist video item list handle.");
		return 0;
	}

	VideoLogInfo("nVideoItemIndex : %d", nVideoFolderIndex);

	if(nVideoFolderIndex < 0 || nVideoFolderIndex >= MpUtilMediaSvcGetVideoFolderListSize())
	{
		VideoLogInfo("Error number of list item.");
		return NULL;
	}

	char *szFolderPath = NULL;
	media_folder_h pFolderItem = (media_folder_h)eina_list_nth(VideoFolderList, nVideoFolderIndex);
	if(pFolderItem)
	{
		media_folder_get_path(pFolderItem, &szFolderPath);

		if(szFolderPath)
		{
			VideoLogInfo("szFolderPath : %s", szFolderPath);
			return szFolderPath;
		}
	}

	return NULL;
}

static bool MpUtilMediaSvcBookmarkItemCb(media_bookmark_h pBookmark, void *pUserData)
{
	VideoLogInfo("");

	media_bookmark_h pAssignBookmark = NULL;
	media_bookmark_clone(&pAssignBookmark, pBookmark);

	GList **pList = (GList**)pUserData;
	*pList = g_list_append(*pList, pAssignBookmark);

	return TRUE;
}

bool MpUtilMediaSvcBookmarkListGet(char *vid, GList **list)
{
	if(!vid)
	{
		VideoLogInfo("No exist vid.");
		return FALSE;
	}

	if(!list)
	{
		VideoLogInfo("No exist list.");
		return FALSE;
	}

	VideoLogInfo("vid : %s", vid);

	filter_h m_FilterHandle = NULL;

	if(media_filter_create(&m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to create media filter handle.");
		return FALSE;
	}

	if(media_filter_set_order(m_FilterHandle, MEDIA_CONTENT_ORDER_ASC, BOOKMARK_MARKED_TIME, MEDIA_CONTENT_COLLATE_DEFAULT) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to set order.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_info_foreach_bookmark_from_db(vid, m_FilterHandle, MpUtilMediaSvcBookmarkItemCb, list) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to get bookmark of video item with filter condition.");
		media_filter_destroy(m_FilterHandle);
		return FALSE;
	}

	if(media_filter_destroy(m_FilterHandle) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("Fail to destroy media filter handle.");
		return FALSE;
	}

	return TRUE;
}

void MpUtilMediaSvcBookmarkListClear(GList *pList)
{
	VideoLogInfo("");

	if(pList == NULL)
	{
		VideoLogInfo("list == NULL\n");
		return;
	}

	media_bookmark_h pBookmarkItem = NULL;

	int nCount = 0;
	int i = 0;

	nCount = g_list_length(pList);
	for(i = 0; i < nCount; i++)
	{
		pBookmarkItem = (void *)g_list_nth_data(pList, i);
		if(pBookmarkItem)
		{
			media_bookmark_destroy(pBookmarkItem);
			pBookmarkItem = NULL;
		}
	}

	g_list_free(pList);
}

int MpUtilMediaSvcBookmarkInsert(char *vid, int position, char *path)
{
	VideoLogInfo("");
	int ret = 0;

	if(vid < 0 || path == NULL)
	{
		VideoLogInfo("Invalid Parameter : %d, %s", vid, path);
		return -1;
	}

	if(media_bookmark_insert_to_db(vid, position, path) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("minfo_add_bookmark ERR : %d", ret);
		return -1;
	}

	return 0;
}

int MpUtilMediaSvcBookmarkDelete(char *vid, int position)
{
	VideoLogInfo("");
	bool ret = 0;

	int bookmarkid = 0;
	char *path = NULL;

	GList *list = NULL;
	media_bookmark_h data = NULL;
	Eina_List *l = NULL;

	ret = MpUtilMediaSvcBookmarkListGet(vid, &list);
	if(ret == FALSE)
	{
		return -1;
	}

	EINA_LIST_FOREACH((Eina_List *)list, l, data)
	{
		if(data)
		{
			time_t nMarkedTime;
			media_bookmark_get_marked_time(data, &nMarkedTime);
			if(position == nMarkedTime)
			{
				media_bookmark_get_bookmark_id(data, &bookmarkid);
				media_bookmark_get_thumbnail_path(data, &path);
				break;
			}
		}
	}

	MpUtilMediaSvcBookmarkListClear(list);

	if(media_bookmark_delete_from_db(bookmarkid) != MEDIA_CONTENT_ERROR_NONE)
	{
		VideoLogInfo("[ERR] media_bookmark_delete_from_db()");
		if(path)
		{
			free(path);
			path = NULL;
		}
		return -1;
	}

	if(path == NULL)
	{
		VideoLogError("Thumbnail path is NULL");
		return -1;
	}

	ecore_file_init();
	if(ecore_file_exists(path))
	{
		if(ecore_file_remove(path))
		{
			VideoLogInfo("Remove success :%s\n", path);
		}
		else
		{
			VideoLogInfo("Remove Failed :%s \n", path);
		}
	}
	else
	{
		VideoLogInfo("The file not eixst :%s\n", path);
	}

	ecore_file_shutdown();

	if(path)
	{
		free(path);
		path = NULL;
	}

	return 0;
}

int MpUtilMediaSvcBookmarkDeleteAll(char *vid)
{
	VideoLogInfo("");
	bool ret = 0;

	int bookmarkid = 0;

	GList *list = NULL;
	media_bookmark_h data = NULL;
	Eina_List *l = NULL;
	char *szThumbnailPath = NULL;

	ret = MpUtilMediaSvcBookmarkListGet(vid, &list);
	if(ret == FALSE)
	{
		return -1;
	}

	EINA_LIST_FOREACH((Eina_List *)list, l, data)
	{
		if(data)
		{
			media_bookmark_get_bookmark_id(data, &bookmarkid);
			media_bookmark_get_thumbnail_path(data, &szThumbnailPath);

			if(szThumbnailPath)
			{
				ecore_file_init();
				if(ecore_file_exists(szThumbnailPath))
				{
					if(ecore_file_remove(szThumbnailPath))
					{
						VideoLogInfo("Remove success : %s", szThumbnailPath);
					}
					else
					{
						VideoLogInfo("Remove Failed : %s", szThumbnailPath);
					}
				}
				else
				{
					VideoLogInfo("The file not eixst :%s", szThumbnailPath);
				}
				ecore_file_shutdown();
			}

			if(media_bookmark_delete_from_db(bookmarkid) != MEDIA_CONTENT_ERROR_NONE)
			{
				VideoLogInfo("[ERR]minfo_delete_bookmark");
				return -1;
			}
		}
	}

	MpUtilMediaSvcBookmarkListClear(list);

	return 0;
}

char* MpUtilMediaSvcBookmarkGetThumbnail(void* pBookmarkItemHandle)
{
	char *szThumbnailPath = NULL;

	media_bookmark_get_thumbnail_path((media_bookmark_h)pBookmarkItemHandle, &szThumbnailPath);

	return szThumbnailPath;
}

int MpUtilMediaSvcBookmarkGetPos(void* pBookmarkItemHandle)
{
	time_t nBookmarkTime;

	media_bookmark_get_marked_time((media_bookmark_h)pBookmarkItemHandle, &nBookmarkTime);

	return (int)nBookmarkTime;
}
