/*
 * Copyright (c) [2012] Samsung Electronics Co., Ltd.
 *
 * Licensed under the Flora License, Version 1.1 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


// CAPI
#include <app.h>
#include <sound_manager.h>

#include <aul.h>
#include <glib.h>
#include <errno.h>
#include <vconf.h>
#include <pmapi.h>
#include <utilX.h>
#include <unistd.h>
#include <E_DBus.h>
#include <signal.h>
#include <Ecore_X.h>
#include <ui-gadget.h>
#include <Ecore_Evas.h>
#include <vconf-keys.h>

#include "mp-util.h"
#include "mp-video-log.h"
#include "mp-util-media-service.h"
#include "mp-video-type-define.h"
#include "mp-video-value-define.h"
#include "mp-video-string-define.h"
//#include "mp-video-info-ctrl.h"

#define MP_LAUNCH_BLUETOOTH_PACKAGE_NAME		"org.tizen.bluetooth"

#define MP_UTIL_USER_AGENT_KEY			"db/admin/uagent"
//#define MP_UTIL_TEMP_USER_AGENT_VALUE	"User-Agent: Mozilla/5.0 (Linux; U; Android 2.2; en-gb; GT-I9000 Build/FROYO) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1"
#define MP_UTIL_TEMP_USER_AGENT_VALUE	"Mozilla/5.0 (SAMSUNG; SAMSUNG-GT-S8500/1.0; U; Bada/1.0; en-us) AppleWebKit/533.1 (KHTML, like Gecko) Dolfin/2.0 Mobile WVGA SMM-MMS/1.2.0 OPN-B"
#define MP_UTIL_MMC_PATH		"/opt/storage/sdcard"
#define MP_UTIL_FILE_PREFIX		"file://"

#define MP_UTIL_ALLSHARE_CHANGE_NOTI	"memory/allshare/status"
#define MP_UTIL_ALLSHARE_NOTI_ON	1
#define MP_UTIL_ALLSHARE_NOTI_OFF	0

#define MP_UTIL_VCONF_KEY_PREVIEW_URL_VIDEOS    "db/private/org.tizen.video-player/preview_url_videos"
#define MP_UTIL_VCONF_KEY_PREVIEW_URL_RECORDS   "db/private/org.tizen.video-player/preview_url_records"

static bool bAlphaSet = TRUE;

static Ecore_X_Window pMainXwindow = 0;
static Ecore_X_Display *pX11DisplayHandle = NULL;

static Evas_Object *pPopUpHandle = NULL;
static Evas_Object *pPopupWindow = NULL;

static MpVideoRotateType nCurRotateValue = VIDEO_ROTATE_PORTRAIT_NORMAL;

/*
 * Callback function
 */

static void MpUtilBatteryStatusChangeCb(keynode_t *pKeyNode, void *pUserData)
{
	VideoLogInfo("");

	int nLowBatteryStatus = 0;

	if (!pUserData) {
		VideoLogInfo("User data is NULL.");
		return;
	}

	VideoAppData *pAppData = (VideoAppData *)pUserData;

	if (!vconf_get_int
	    (VCONFKEY_SYSMAN_BATTERY_STATUS_LOW, &nLowBatteryStatus)) {
		if (nLowBatteryStatus <= VCONFKEY_SYSMAN_BAT_POWER_OFF) {
			/* MpUtilNotifyPopUp(pAppData, MP_COM_BODY_LOW_BATTERY, MpUtilBatteryExitCb); */
			pAppData->VideoAppCtrlCallbackFunc.VideoAppCtrlExit(pAppData);
			return;
		}
	} else {
		VideoLogInfo("Fail to get vconf");
	}
}

static void MpUtilMMCStatusChangeCb(keynode_t * pKeyNode, void *pUserData)
{
	VideoLogInfo("");

	char szFilename[9] = { 0 };

	if (!pUserData || !pKeyNode) {
		VideoLogInfo("User data is NULL.");
		return;
	}

	VideoAppData *pAppData = (VideoAppData *)pUserData;
	char *keyname = vconf_keynode_get_name(pKeyNode);
	if (strcmp(keyname, VCONFKEY_FILEMANAGER_DB_STATUS) == 0) {
		int nMMCState = vconf_keynode_get_int(pKeyNode);
		if (nMMCState == VCONFKEY_FILEMANAGER_DB_UPDATED) {
			strncpy(szFilename, pAppData->szMediaUri, sizeof(szFilename) - 1);
			VideoLogInfo("FILE NAME[%s]", szFilename);
			if (!strcmp(MP_UTIL_MMC_PATH, szFilename)) {
				/* MpUtilNotifyPopUp(pAppData, "MMC card is ejected", NULL); */
				pAppData->VideoAppCtrlCallbackFunc.VideoAppCtrlExit(pAppData);
			}
		}
	} else {
		VideoLogInfo("Fail to get vconf");
	}
}


static void MpUtilSoundMgrVolumeChangeCb(sound_type_e nType, unsigned int nVolume, void *pUserData)
{
	VideoLogInfo("");

	//char szFilename[9] = { 0 };

	if (!pUserData ) {
		VideoLogInfo("User data is NULL.");
		return;
	}

	if(nType != (sound_type_e)VOLUME_KEY_TYPE_MEDIA)
	{
		return;
	}

	bool bMute = FALSE;

	if(nVolume == 0)
	{
		bMute = TRUE;
	}

	VideoAppData *pAppData = (VideoAppData *)pUserData;
	pAppData->VideoAppCtrlCallbackFunc.VideoAppCtrlSetMute(pAppData, bMute);

}
/*
 * External function
 */

void MpUtilExitVideoPlayer(void)
{
	VideoLogInfo("");

	elm_exit();
}

static void MpUtilDestroyMainWindow(void *pUserData, Evas_Object *pEvasObject,
				    void *pEvent)
{
	VideoLogInfo("");

	MpUtilExitVideoPlayer();
}

void MpUtilResetForRelaunching(void)
{
	VideoLogInfo("");

	pX11DisplayHandle = NULL;
	pPopUpHandle = NULL;
	pPopupWindow = NULL;
}

void MpUtilSetAlphaOfMainWindow(bool bSetAlpha)
{
	VideoLogInfo("");

	if(bSetAlpha)
	{
	}
	else
	{
	}
	bAlphaSet = bSetAlpha;
}

void *MpUtilCreateMainWindow(const char *pStrName)
{
	VideoLogInfo("");

	if (!pStrName) {
		VideoLogInfo("[ERR] No exist pStrName.");
		return NULL;
	}

	if (pMainXwindow) {
		evas_object_del((Evas_Object *)pMainXwindow);
		pMainXwindow = 0;
	}

	Evas_Object *pEvasObject;

	pEvasObject = elm_win_add(NULL, pStrName, ELM_WIN_BASIC);
	if (pEvasObject) {
		elm_win_title_set(pEvasObject, pStrName);
		evas_object_smart_callback_add(pEvasObject, "delete,request",
					       MpUtilDestroyMainWindow, NULL);
		elm_win_borderless_set(pEvasObject, EINA_FALSE);
	}

	Evas *pEvas = evas_object_evas_get(pEvasObject);
	Evas_Object *pMainRect = evas_object_rectangle_add(pEvas);

	if (pMainRect)
	{
		evas_object_size_hint_weight_set(pMainRect, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
		evas_object_color_set(pMainRect, 0, 0, 0, 0);
		evas_object_render_op_set(pMainRect, EVAS_RENDER_COPY);
		evas_object_show(pMainRect);
		elm_win_resize_object_add(pEvasObject, pMainRect);
	}
	pMainXwindow = elm_win_xwindow_get(pEvasObject);

	return (void *)pEvasObject;
}

int MpUtilSetKeyGrab(const char *szKeyName, int nGrabMode)
{
	VideoLogInfo("");
	if (!pX11DisplayHandle) {
		pX11DisplayHandle = ecore_x_display_get();
	}

	if (!pMainXwindow) {
		VideoLogInfo("Not exist pMainXwindow.");
	}

	utilx_grab_key(pX11DisplayHandle, pMainXwindow, szKeyName, nGrabMode);
	return TRUE;
}

int MpUtilSetKeyUngrab(const char *szKeyName)
{
	VideoLogInfo("");
	if (pMainXwindow && pX11DisplayHandle) {
		utilx_ungrab_key(pX11DisplayHandle, pMainXwindow, szKeyName);
	}
	return TRUE;
}


bool MpUtilCheckRTSPType(char *szUriPath)
{
	if(szUriPath == NULL) {
		VideoLogInfo("ERR:");
		return FALSE;
	}

	//VideoLogInfo(" URI : %s", szUriPath);

	if (strstr(szUriPath, "rtp"))
		return TRUE;
	else if (strstr(szUriPath, "rtsp"))
		return TRUE;

	return FALSE;
}

int MpUtilCheckUriType(char *szUriPath)
{
	if(szUriPath == NULL) {
		VideoLogInfo("ERR:");
		return FALSE;
	}

	VideoLogInfo(" URI : %s", szUriPath);

	if (strstr(szUriPath, "rtp"))
		return 1;
	else if (strstr(szUriPath, "rtsp"))
		return 1;
	else if (strstr(szUriPath, "http"))
		return 1;
	else if (strstr(szUriPath, "https"))
		return 1;

	return 0;
}

bool MpUtilCheckLocalFileExist(char *uri)
{
	VideoLogInfo("");

	if(uri == NULL)
	{
		VideoLogInfo("[ERR]");
		return FALSE;
	}

	if(strstr(uri,MP_UTIL_FILE_PREFIX))
	{
		if (!g_file_test(uri+strlen(MP_UTIL_FILE_PREFIX), G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
		{
			return FALSE;
		}
		return TRUE;
	}
	else
	{
		if(!g_file_test(uri, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
		{
			return FALSE;
		}
		return TRUE;
	}
}

bool MpUtilCheckBatteryStatus(void)
{
	VideoLogInfo("");

	int nLowBatteryStatus = 0;

	if (!vconf_get_int
	    (VCONFKEY_SYSMAN_BATTERY_STATUS_LOW, &nLowBatteryStatus)) {
		if (nLowBatteryStatus <= VCONFKEY_SYSMAN_BAT_POWER_OFF) {
			return FALSE;
		}
	}

	return TRUE;
}

int MpUtilBatteryStatusNoti(VideoAppData *pAppData)
{
	VideoLogInfo("");

	if(!pAppData)
	{
		VideoLogInfo("[ERR] No exist appdata.");
		return FALSE;
	}

	if(vconf_notify_key_changed(VCONFKEY_SYSMAN_BATTERY_STATUS_LOW, MpUtilBatteryStatusChangeCb, pAppData))
	{
		VideoLogInfo("[ERR] Fail to set Battery notification.");
		/* return FALSE; */
	}

	return TRUE;
}

int MpUtilBatteryStatusNotiIgnore(void)
{
	VideoLogInfo("");

	if (vconf_ignore_key_changed
	    (VCONFKEY_SYSMAN_BATTERY_STATUS_LOW,
	     MpUtilBatteryStatusChangeCb) < 0) {
		VideoLogInfo("[ERR] Fail to ignore battery status.");
		return FALSE;
	}

	return TRUE;
}

int MpUtilMMCstatusNoti(VideoAppData *pAppData)
{
	VideoLogInfo("");

	if (!pAppData) {
		VideoLogInfo("[ERR] No exist appdata.");
		return FALSE;
	}

	if (vconf_notify_key_changed
	    (VCONFKEY_FILEMANAGER_DB_STATUS, MpUtilMMCStatusChangeCb,
	     pAppData) < 0) {
		VideoLogInfo("[ERR] Fail to set MMC notification.");
		//return FALSE;
	}

	return TRUE;
}

int MpUtilMMCstatusNotiIgnore(void)
{
	VideoLogInfo("");

	if (vconf_ignore_key_changed
	    (VCONFKEY_FILEMANAGER_DB_STATUS, MpUtilMMCStatusChangeCb) < 0) {
		VideoLogInfo("[ERR] Fail to ignore MMC status.");
		//return FALSE;
	}

	return TRUE;
}

int MpUtilGetRotationStateFromAppcore(void)
{
	VideoLogInfo("");
	int bLocked = -1;

	if (vconf_get_bool(VCONFKEY_SETAPPL_ROTATE_LOCK_BOOL, &bLocked) != 0)
	{
		VideoLogInfo("Get vlalue fail");
		return nCurRotateValue;
	}

	if(bLocked == false)
	{
		switch(app_get_device_orientation())
		{
		case APP_DEVICE_ORIENTATION_0:
			VideoLogInfo("VIDEO_ROTATE_PORTRAIT_NORMAL");
			nCurRotateValue = VIDEO_ROTATE_PORTRAIT_NORMAL;
			break;

		case APP_DEVICE_ORIENTATION_90:
			VideoLogInfo("VIDEO_ROTATE_PORTRAIT_REVERSE");
			nCurRotateValue = VIDEO_ROTATE_LANDSCAPE_REVERSE;
			break;

		case APP_DEVICE_ORIENTATION_180:
			VideoLogInfo("VIDEO_ROTATE_LANDSCAPE_NORMAL");
			nCurRotateValue = VIDEO_ROTATE_PORTRAIT_REVERSE;
			break;

		case APP_DEVICE_ORIENTATION_270:
			VideoLogInfo("VIDEO_ROTATE_LANDSCAPE_REVERSE");
			nCurRotateValue = VIDEO_ROTATE_LANDSCAPE_NORMAL;
			break;
		}
	}
	return nCurRotateValue;
}

int MpUtilGetRotationState(void)
{
	VideoLogInfo("");

	return nCurRotateValue;
}

void MpUtilSetRotationState(int nCurRotation)
{
	VideoLogInfo("");

	nCurRotateValue = nCurRotation;

	if (pPopupWindow) {
		MpUtilRotateWindow(nCurRotation, pPopupWindow);
	}
}

bool MpUtilGetTitleFromFilepath(char *szFilepath, char *szTitle, int nLengthTitle)
{
	VideoLogInfo("");

	if (!szFilepath || !szTitle) {
		VideoLogInfo("[ERR]");
		return FALSE;
	}

	char *szTitleName;
	char *szExt;

	memset(szTitle, 0, nLengthTitle);

	szTitleName = strrchr(szFilepath, '/');

	if (szTitleName)
		szTitleName++;
	else
		szTitleName = szFilepath;

	szExt = strrchr(szTitleName, '.');

	if (szExt) {
		int nTmpStringSize = szExt - szTitleName;
		strncpy(szTitle, szTitleName, nTmpStringSize);
	} else {
		strncpy(szTitle, szTitleName, STR_LEN_MAX - 1);
	}

	return TRUE;
}

void MpUtilInitSession(void)
{
	VideoLogInfo("");

	sound_manager_set_session_type(SOUND_SESSION_TYPE_EXCLUSIVE);
}

void MpUtilFinishSession(void)
{
	VideoLogInfo("");
	//sound_manager_set_session_type(SOUND_SESSION_TYPE_SHARE);
}

void MpUtilVolumeTypeSet(void)
{
	VideoLogInfo("");

	sound_manager_set_volume_key_type(VOLUME_KEY_TYPE_MEDIA);
}

void MpUtilVolumeTypeUnset(void)
{
	VideoLogInfo("");

	 sound_manager_set_volume_key_type(VOLUME_KEY_TYPE_NONE);
}

bool MpUtilCheckMuteStatus()
{
	VideoLogInfo("");

	int nVolume = 0;
	int nRet = 0;
	nRet = sound_manager_get_volume(VOLUME_KEY_TYPE_MEDIA, &nVolume);
	if(nRet != SOUND_MANAGER_ERROR_NONE)
	{
		VideoLogError("sound_manager_get_volume fail : %d", nRet);
		return FALSE;
	}

	if(nVolume == 0)
	{
		return TRUE;
	}
	return FALSE;
}

bool MpUtilSetVolumeChangeCbSet(void *pUserData)
{
	int ret = 0;
	VideoLogInfo("");

	ret = sound_manager_set_volume_changed_cb(MpUtilSoundMgrVolumeChangeCb, pUserData);
	if(ret != SOUND_MANAGER_ERROR_NONE)
	{
		VideoLogError("sound_manager_set_volume_changed_cb fail : %d", ret);
		return FALSE;
	}

	return TRUE;
}
void MpUtilSetVolumeChangeCbUnset()
{
	VideoLogInfo("");

	sound_manager_unset_volume_changed_cb();

}

void MpUtilDeletePopupHandle(void)
{
	VideoLogInfo("");

	if (pPopUpHandle) {
		evas_object_del(pPopUpHandle);
		pPopUpHandle = NULL;
	} else {
		VideoLogInfo("No exist popup.");
	}

	if (pPopupWindow) {
		evas_object_del(pPopupWindow);
		pPopupWindow = NULL;
	} else {
		VideoLogInfo("No exist popup window.");
	}

	MpUtilSetAlphaOfMainWindow(TRUE);
}

bool MpUtilNotifyPopUp(VideoAppData *pAppData, char *szContents, void *PopupButtonCallbackFunc)
{
	VideoLogInfo("");

	if (pAppData == NULL || szContents == NULL) {
		VideoLogInfo("No have popup message or pAppData is null.");
		return FALSE;
	}

	MpUtilDeletePopupHandle();

	MpUtilSetAlphaOfMainWindow(FALSE);

	pPopUpHandle = elm_popup_add(pAppData->pMainWindow);

	evas_object_size_hint_weight_set(pPopUpHandle, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	elm_object_text_set(pPopUpHandle, szContents);
	elm_object_part_text_set(pPopUpHandle, "title,text", MP_COM_POP_ERROR);
	elm_popup_timeout_set(pPopUpHandle, 3.0);

	if(PopupButtonCallbackFunc)
	{
		evas_object_smart_callback_add(pPopUpHandle, "timeout", PopupButtonCallbackFunc, (void *)pAppData);
	}

	if(pPopupWindow)
	{
		MpUtilRotateWindow(MpUtilGetRotationState(), pPopupWindow);
	}

	evas_object_show(pPopUpHandle);

	return TRUE;
}

bool MpUtilWarinigPopUp(VideoAppData *pAppData, char *szContents,
		       void *PopupButtonCallbackFunc)
{
	VideoLogInfo("");

	if (pAppData == NULL || szContents == NULL) {
		VideoLogInfo("No have popup message or pAppData is null.");
		return FALSE;
	}

	MpUtilDeletePopupHandle();

	MpUtilSetAlphaOfMainWindow(FALSE);

	pPopUpHandle = elm_popup_add(pAppData->pMainWindow);

	evas_object_size_hint_weight_set(pPopUpHandle, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	elm_object_text_set(pPopUpHandle, szContents);
	elm_object_part_text_set(pPopUpHandle, "title,text", MP_COM_POP_ERROR);
	elm_popup_timeout_set(pPopUpHandle, 3.0);

	if (PopupButtonCallbackFunc) {
		evas_object_smart_callback_add(pPopUpHandle, "timeout", PopupButtonCallbackFunc, (void *)pAppData);
	}

	evas_object_show(pPopUpHandle);

	return TRUE;
}


bool MpUtilYesNoPopUp(VideoAppData *pAppData, char *szTitle, char *szContents, void *PopupYesButtonCallbackFunc, void *PopupNoButtonCallbackFunc)
{
	VideoLogInfo("");

	if(szTitle == NULL || szContents == NULL || pAppData == NULL)
	{
		VideoLogInfo("No have popup message or pAppData is null.");
		return FALSE;
	}

	Evas_Object *pButton = NULL;

	MpUtilDeletePopupHandle();

	MpUtilSetAlphaOfMainWindow(FALSE);

	pPopUpHandle = elm_popup_add(pAppData->pMainWindow);

	evas_object_size_hint_weight_set(pPopUpHandle, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	elm_object_text_set(pPopUpHandle, szContents);
	elm_object_part_text_set(pPopUpHandle, "title,text", szTitle);

	pButton = elm_button_add(pPopUpHandle);
	elm_object_style_set ( pButton, "popup_button/default");
	elm_object_text_set(pButton, MP_COM_SK_YES);
	elm_object_part_content_set(pPopUpHandle, "button1", pButton);

	if(PopupYesButtonCallbackFunc)
	{
		evas_object_smart_callback_add(pButton, "clicked", PopupYesButtonCallbackFunc, (void*)pAppData);
	}

	pButton = elm_button_add(pPopUpHandle);
	elm_object_text_set(pButton, MP_COM_SK_NO);
	elm_object_style_set ( pButton, "popup_button/default");
	elm_object_part_content_set(pPopUpHandle, "button2", pButton);

	if(PopupNoButtonCallbackFunc)
	{
		evas_object_smart_callback_add(pButton, "clicked", PopupNoButtonCallbackFunc, (void*)pAppData);
	}

	//elm_popup_timeout_set(pPopUpHandle, 3.0);

	evas_object_show(pPopUpHandle);

	return TRUE;
}

bool MpUtilRemoveQuestionPopUp(VideoAppData *pAppData, void *PopupDeleteButtonCallbackFunc, void *PopupCancelButtonCallbackFunc, void *pUserData)
{
	VideoLogInfo("");

	if(pAppData == NULL)
	{
		VideoLogInfo("No have popup message or pAppData is null.");
		return FALSE;
	}

	Evas_Object *pButton = NULL;

	MpUtilDeletePopupHandle();

	MpUtilSetAlphaOfMainWindow(FALSE);

	pPopUpHandle = elm_popup_add(pAppData->pMainWindow);

	evas_object_size_hint_weight_set(pPopUpHandle, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	elm_object_part_text_set(pPopUpHandle, "title,text", MP_COM_BODY_DELETE_Q);

	pButton = elm_button_add(pPopUpHandle);
	elm_object_text_set(pButton, MP_COM_BODY_DELETE);
	elm_object_style_set(pButton, "sweep/delete");
	elm_object_part_content_set(pPopUpHandle, "button1", pButton);

	if(PopupDeleteButtonCallbackFunc)
	{
		evas_object_smart_callback_add(pButton, "clicked", PopupDeleteButtonCallbackFunc, pUserData);
	}

	pButton = elm_button_add(pPopUpHandle);
	elm_object_text_set(pButton, MP_COM_BUTTON_CANCEL);
	elm_object_part_content_set(pPopUpHandle, "button2", pButton);

	if(PopupCancelButtonCallbackFunc)
	{
		evas_object_smart_callback_add(pButton, "clicked", PopupCancelButtonCallbackFunc, pUserData);
	}

	//elm_popup_timeout_set(pPopUpHandle, 3.0);

	evas_object_show(pPopUpHandle);

	return TRUE;
}

void MpUtilSetLabelForDetail(Evas_Object *pBox, char *szString)
{
	VideoLogInfo("");

	Evas_Object *pLabel = NULL;

	pLabel = elm_label_add(pBox);
	elm_object_style_set(pLabel, "popup/default");
	elm_object_text_set(pLabel, szString);
	elm_label_ellipsis_set(pLabel, EINA_TRUE);
	elm_label_wrap_width_set(pLabel, 614 * elm_config_scale_get());
	evas_object_size_hint_weight_set(pLabel, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	evas_object_size_hint_min_set(pLabel, 614 * elm_config_scale_get(), 35 * elm_config_scale_get());
	elm_box_pack_end(pBox, pLabel);
	evas_object_show(pLabel);
}

/*bool MpUtilDetailPopup(VideoAppData *pAppData, int nVideoItemIndex, char *szTitle, void *PopupButtonCallbackFunc)
{
	VideoLogInfo("");

	if(szTitle == NULL || pAppData == NULL)
	{
		VideoLogInfo("No have popup message or pAppData is null.");
		return FALSE;
	}
	char *szFilePath = NULL;
	char *szVideoTitle = NULL;

	char szTmpStr[STR_LEN_MAX] = {0};
	char szTmpFileDate[STR_LEN_MAX] = {0};
	char szTmpFileExtension[STR_LEN_MAX] = {0};
	char szTmpFileSize[STR_LEN_MAX] = {0};

	double nLongtitude = 0.0;
	double nLatitude = 0.0;

	int nWidth = 0;
	int nHeight = 0;

	Evas_Object *pBox = NULL;
	Evas_Object *pButton = NULL;

	MpUtilDeletePopupHandle();

	MpUtilSetAlphaOfMainWindow(FALSE);

	pPopUpHandle = elm_popup_add(pAppData->pMainWindow);

	evas_object_size_hint_weight_set(pPopUpHandle, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);

	szFilePath = MpUtilMediaSvcGetVideoUrl(nVideoItemIndex);
	szVideoTitle = MpUtilMediaSvcGetVideoTitle(nVideoItemIndex);
	nWidth = MpUtilMediaSvcGetVideoItemWidth(nVideoItemIndex);
	nHeight = MpUtilMediaSvcGetVideoItemHeight(nVideoItemIndex);

	MpVideoInfoCtrlGetFileInfo(szFilePath, szTmpFileDate, STR_LEN_MAX, szTmpFileExtension, STR_LEN_MAX, szTmpFileSize, STR_LEN_MAX);
	MpVideoInfoCtrlGetGPS(szFilePath, &nLongtitude, &nLatitude);

	pBox = elm_box_add(pPopUpHandle);

	snprintf(szTmpStr, STR_LEN_MAX, "<font_size=32><align=left> %s: %s </align></font_size>", MP_COM_BODY_DETAILS_TITLE, szVideoTitle);
	MpUtilSetLabelForDetail(pBox, szTmpStr);
	memset(szTmpStr, 0, STR_LEN_MAX);

	snprintf(szTmpStr, STR_LEN_MAX, "<font_size=32><align=left> %s: %s</align></font_size>", MP_COM_BODY_FORMAT, szTmpFileExtension);
	MpUtilSetLabelForDetail(pBox, szTmpStr);
	memset(szTmpStr, 0, STR_LEN_MAX);

	snprintf(szTmpStr, STR_LEN_MAX, "<font_size=32><align=left> %s: %s</align></font_size>", MP_COM_POP_DATE, szTmpFileDate);
	MpUtilSetLabelForDetail(pBox, szTmpStr);
	memset(szTmpStr, 0, STR_LEN_MAX);

	snprintf(szTmpStr, STR_LEN_MAX, "<font_size=32><align=left> %s: %s</align></font_size>", MP_COM_BODY_SIZE, szTmpFileSize);
	MpUtilSetLabelForDetail(pBox, szTmpStr);
	memset(szTmpStr, 0, STR_LEN_MAX);

	snprintf(szTmpStr, STR_LEN_MAX, "<font_size=32><align=left> %s: %d x %d</align></font_size>", MP_IDLE_BODY_RESOLUTION, nWidth, nHeight);
	MpUtilSetLabelForDetail(pBox, szTmpStr);
	memset(szTmpStr, 0, STR_LEN_MAX);

	snprintf(szTmpStr, STR_LEN_MAX, "<font_size=32><align=left> %s: %f</align></font_size>", _(MP_VPL_GPS_LATITUDE), nLatitude);
	MpUtilSetLabelForDetail(pBox, szTmpStr);
	memset(szTmpStr, 0, STR_LEN_MAX);

	snprintf(szTmpStr, STR_LEN_MAX, "<font_size=32><align=left> %s: %f</align></font_size>", _(MP_VPL_GPS_LONGITUTD), nLongtitude);
	MpUtilSetLabelForDetail(pBox, szTmpStr);
	memset(szTmpStr, 0, STR_LEN_MAX);

	elm_object_content_set(pPopUpHandle, pBox);

	elm_object_part_text_set(pPopUpHandle, "title,text", szTitle);
	pButton = elm_button_add(pPopUpHandle);
	elm_object_style_set (pButton, "popup_button/default");
	elm_object_text_set(pButton, MP_COM_SK_BACK);
	elm_object_part_content_set(pPopUpHandle, "button1", pButton);

	if(szFilePath)
	{
		free(szFilePath);
		szFilePath = NULL;
	}

	if(szVideoTitle)
	{
		free(szVideoTitle);
		szVideoTitle = NULL;
	}

	if(PopupButtonCallbackFunc)
	{
		evas_object_smart_callback_add(pButton, "clicked", PopupButtonCallbackFunc, (void*)pAppData);
	}

	evas_object_show(pPopUpHandle);

	return TRUE;
}*/

bool MpUtilProgressPopUp(VideoAppData *pAppData, char *szLabel)
{
	VideoLogInfo("");

	if (pAppData == NULL || szLabel == NULL) {
		VideoLogInfo("No have popup message or pAppData is null.");
		return FALSE;
	}

	MpUtilDeletePopupHandle();

	MpUtilSetAlphaOfMainWindow(FALSE);

	pPopUpHandle = elm_popup_add(pAppData->pMainWindow);

	evas_object_size_hint_weight_set(pPopUpHandle, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	Evas_Object *progressbar, *box, *label;

	label = elm_label_add(pPopUpHandle);
	elm_object_text_set(label, szLabel);
	evas_object_show(label);

	progressbar = elm_progressbar_add(pPopUpHandle);
	elm_object_style_set(progressbar, "pending_list");
	elm_progressbar_pulse(progressbar, EINA_TRUE);
	evas_object_size_hint_align_set(progressbar, EVAS_HINT_FILL, 0.5);
	evas_object_size_hint_weight_set(progressbar, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	elm_progressbar_pulse(progressbar, EINA_TRUE);
	evas_object_show(progressbar);

	box = elm_box_add(pPopUpHandle);
	elm_box_pack_end(box, label);
	elm_box_pack_end(box, progressbar);
	evas_object_show(box);
	elm_object_content_set(pPopUpHandle, box);

	if (pPopupWindow) {
	MpUtilRotateWindow(MpUtilGetRotationState(), pPopupWindow);
	}

	evas_object_show(pPopUpHandle);

	return TRUE;
}


void *MpUtilCreateButtonIcon(void *pParent, const char *szIconPath, bool bSizeUp, bool bSizeDown, int nAspectWidth, int nAspectHeight, void *pUserData, char* szButtonStyle, void *func)
{
	VideoLogInfo("");

	Evas_Object *pButton = NULL;
	Evas_Object *pIcon = NULL;

	pButton = elm_button_add(pParent);

	if(szIconPath)
	{
		pIcon = elm_icon_add(pParent);
		elm_image_file_set(pIcon, szIconPath, NULL);
		//evas_object_size_hint_aspect_set(pIcon, EVAS_ASPECT_CONTROL_VERTICAL, nAspectWidth, nAspectHeight);
		evas_object_size_hint_aspect_set(pIcon, EVAS_ASPECT_CONTROL_NEITHER, nAspectWidth, nAspectHeight);
		//elm_icon_resizable_set(pIcon, bSizeUp, bSizeDown);
	}

	if(szButtonStyle)
	{
		elm_object_style_set(pButton, szButtonStyle);
	}

	if(pIcon)
	{
		elm_object_part_content_set(pButton,PART_BUTTON_ICON, pIcon);
	}

	if(func)
	{
		evas_object_smart_callback_add(pButton, "clicked", func, (void *)pUserData);
	}

	elm_object_focus_allow_set(pButton, EINA_FALSE);
	evas_object_size_hint_weight_set(pButton, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	evas_object_show(pButton);

	return (void *)pButton;
}

void *MpUtilCreateStyleButton(void *pParent, const char* szButtonText, const void *pUserData, char* szButtonStyle, void *func)
{
	VideoLogInfo("");

	Evas_Object *pButton = NULL;

	pButton = elm_button_add(pParent);

	if(szButtonStyle)
	{
		elm_object_style_set(pButton, szButtonStyle);
	}

	if(szButtonText)
	{
		elm_object_text_set(pButton, szButtonText);
	}

	if(func)
	{
		evas_object_smart_callback_add(pButton, "clicked", func, pUserData);
	}

	elm_object_focus_allow_set(pButton, EINA_FALSE);
	evas_object_size_hint_weight_set(pButton, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	evas_object_show(pButton);

	return (void *)pButton;
}

void *MpUtilLoadEdjFile(Evas * pEvas, char *szEdjName, char *szGroupName)
{
	VideoLogInfo("");

	Evas_Object *pEdj = NULL;
	int nWidth = 0;
	int nHeight = 0;

	pEdj = edje_object_add(pEvas);
	if (!edje_object_file_set(pEdj, szEdjName, szGroupName)) {
		VideoLogInfo("[ERR] EDJ file error : %s | %s\n", szEdjName,
			     szGroupName);
		return NULL;
	}

	edje_object_size_min_get(pEdj, &nWidth, &nHeight);
	evas_object_resize(pEdj, nWidth, nHeight);

	return (void *)pEdj;
}

bool MpUtilIsCallOff(void)
{
	VideoLogInfo("");

	int nCallStatus = 0;

	if (!vconf_get_int(VCONFKEY_CALL_STATE, &nCallStatus)) {
		if (nCallStatus == VCONFKEY_CALL_OFF)
		{
			VideoLogInfo("Call off");
			return TRUE;
		}
		else
		{
			VideoLogInfo("!!! CALL ON !!!");
			return FALSE;
		}
	}

	return TRUE;
}

bool MpUtilIsCameraOff(void)
{
	VideoLogInfo("");

	int nCameraStatus = 0;

	if (!vconf_get_int(VCONFKEY_CAMERA_STATE, &nCameraStatus)) {
		if (nCameraStatus == VCONFKEY_CAMERA_STATE_NULL)
		{
			VideoLogInfo("Camera off");
			return TRUE;
		}
		else
		{
			VideoLogInfo("!!! CAMERA ON !!!");
		}
	}

	return FALSE;
}

bool MpUtilRegisteCameraStatusCbFunc(void *pCameraStatusCb, void *pUserData)
{
	if (!pCameraStatusCb) {
		VideoLogInfo("pEarjackCb is empty.");
		return FALSE;
	}

	VideoLogInfo("");

	vconf_notify_key_changed(VCONFKEY_CAMERA_STATE, pCameraStatusCb, pUserData);

	return TRUE;
}

bool MpUtilIsConnectEarjack(void)
{
	VideoLogInfo("");

	int nEarjack = 0;

	if (!vconf_get_int(VCONFKEY_SYSMAN_EARJACK, &nEarjack)) {
		if (nEarjack) {
			return TRUE;
		}
	}

	return FALSE;
}

bool MpUtilRegisteEarjackCbFunc(void *pEarjackCb, void *pUserData)
{
	if (!pEarjackCb) {
		VideoLogInfo("pEarjackCb is empty.");
		return FALSE;
	}

	VideoLogInfo("");

	vconf_notify_key_changed(VCONFKEY_SYSMAN_EARJACK, pEarjackCb, pUserData);

	return TRUE;
}

bool MpUtilSetPreviewUrlVideos(char* szPreviewUrl)
{
	if(!szPreviewUrl || strlen(szPreviewUrl) <= 0)
	{
		VideoLogInfo("[ERR]");
	}

	VideoLogInfo("szPreviewUrl : %s", szPreviewUrl);

	bool bRet = FALSE;

	if(vconf_set_str(MP_UTIL_VCONF_KEY_PREVIEW_URL_VIDEOS, szPreviewUrl))
	{
		VideoLogInfo("Fail to write szPreviewUrl.");
		bRet = FALSE;
	}
	else
	{
		VideoLogInfo("Success to write it.");
		bRet = TRUE;
	}

	return bRet;
}

bool MpUtilGetPreviewUrlVideos(char* szRetPreviewUrl, int nStrSize)
{
	if(!szRetPreviewUrl)
	{
		VideoLogInfo("[ERR]");
	}
	else
	{
		memset(szRetPreviewUrl, 0, nStrSize);
	}

	VideoLogInfo("");

	bool bRet = FALSE;
	char *szPreviewUrl = NULL;


	szPreviewUrl = vconf_get_str(MP_UTIL_VCONF_KEY_PREVIEW_URL_VIDEOS);
	if(!szPreviewUrl || strlen(szPreviewUrl) <= 0)
	{
		VideoLogInfo("Fail to get szPreviewUrl from vconf register.");
		bRet = FALSE;
	}
	else
	{
		VideoLogInfo("Success to get szPreviewUrl. : %s", szPreviewUrl);
		strncpy(szRetPreviewUrl, szPreviewUrl, nStrSize - 1);
		free(szPreviewUrl);
		bRet = TRUE;
	}

	return bRet;
}

bool MpUtilSetPreviewUrlRecords(char* szPreviewUrl)
{
	if(!szPreviewUrl || strlen(szPreviewUrl) <= 0)
	{
		VideoLogInfo("[ERR]");
	}

	VideoLogInfo("");

	bool bRet = FALSE;

	if(vconf_set_str(MP_UTIL_VCONF_KEY_PREVIEW_URL_RECORDS, szPreviewUrl))
	{
		VideoLogInfo("Fail to write szPreviewUrl.");
		bRet = FALSE;
	}
	else
	{
		VideoLogInfo("Success to write it.");
		bRet = TRUE;
	}

	return bRet;
}

bool MpUtilGetPreviewUrlRecords(char* szRetPreviewUrl, int nStrSize)
{
	if(!szRetPreviewUrl)
	{
		VideoLogInfo("[ERR]");
	}
	else
	{
		memset(szRetPreviewUrl, 0, nStrSize);
	}

	VideoLogInfo("");

	bool bRet = FALSE;
	char *szPreviewUrl = NULL;


	szPreviewUrl = vconf_get_str(MP_UTIL_VCONF_KEY_PREVIEW_URL_RECORDS);
	if(!szPreviewUrl || strlen(szPreviewUrl) <= 0)
	{
		VideoLogInfo("Fail to get szPreviewUrl from vconf register.");
		bRet = FALSE;
	}
	else
	{
		VideoLogInfo("Success to get szPreviewUrl. : %s", szPreviewUrl);
		strncpy(szRetPreviewUrl, szPreviewUrl, nStrSize - 1);
		free(szPreviewUrl);
		bRet = TRUE;
	}

	return bRet;
}

unsigned int MpUtilGetMainWindowXID(void)
{
	VideoLogInfo("");
	if (pMainXwindow) {
		VideoLogInfo("pMainXwindow : %d", pMainXwindow);
		return pMainXwindow;
	} else {
		VideoLogInfo("No exist main window XID.");
	}
	return 0;
}

void MpUtilRotateWindow(int nRotateMode, void *pWindowHandle)
{
	VideoLogInfo("");

	if (!pWindowHandle) {
		return;
	}

	switch (nRotateMode) {
	case VIDEO_ROTATE_UNKNOWN:
		VideoLogInfo("VIDEO_ROTATE_UNKNOWN");
		elm_win_rotation_with_resize_set(pWindowHandle, 0);
		break;

	case VIDEO_ROTATE_PORTRAIT_NORMAL:
		VideoLogInfo("VIDEO_ROTATE_PORTRAIT_NORMAL");
		elm_win_rotation_with_resize_set(pWindowHandle, 0);
		break;

	case VIDEO_ROTATE_LANDSCAPE_NORMAL:
		VideoLogInfo("VIDEO_ROTATE_LANDSCAPE_NORMAL");
		elm_win_rotation_with_resize_set(pWindowHandle, 270);
		break;

	case VIDEO_ROTATE_PORTRAIT_REVERSE:
		VideoLogInfo("VIDEO_ROTATE_PORTRAIT_REVERSE");
		elm_win_rotation_with_resize_set(pWindowHandle, 180);
		break;

	case VIDEO_ROTATE_LANDSCAPE_REVERSE:
		VideoLogInfo("VIDEO_ROTATE_LANDSCAPE_REVERSE");
		elm_win_rotation_with_resize_set(pWindowHandle, 90);
		break;

	default:
		VideoLogInfo("DEFAULT - VIDEO_ROTATE_UNKNOWN");
		elm_win_rotation_with_resize_set(pWindowHandle, 0);
		break;
	}
}

void MpUtilGetUserAgent(VideoAppData *pAppData)
{
	VideoLogInfo("");

	int nWifiMode = 0;

	char *szUserAgent = NULL;
	szUserAgent = vconf_get_str(VCONFKEY_ADMIN_UAGENT);
	if(szUserAgent)
	{
		memset(pAppData->szUserAgent, 0, STR_LEN_MAX);
		strncpy(pAppData->szUserAgent, szUserAgent, STR_LEN_MAX - 1);
		free(szUserAgent);
	}
	else
	{
		VideoLogInfo("!!!!! NO EXIST USER AGENT !!!!!");
	}

#if 0
	memset(pAppData->szUserAgent, 0, STR_LEN_MAX);
	snprintf(pAppData->szUserAgent, STR_LEN_MAX, "%s", MP_UTIL_TEMP_USER_AGENT_VALUE);
#endif

	if(!vconf_get_int(VCONFKEY_WIFI_STATE, &nWifiMode))
	{
		VideoLogInfo("User Agent : %s, Wi-Fi : %d", pAppData->szUserAgent, nWifiMode);
	}

}

double MpUtilGetSysTime(void)
{
	struct timeval tv;

	gettimeofday(&tv, NULL);
	return (double)tv.tv_sec + (double)tv.tv_usec / 1E6;
}

void MpUtilLcdNormalPowerLockForResume(void)
{
	VideoLogInfo("");

	pm_lock_state(LCD_NORMAL, GOTO_STATE_NOW | HOLD_KEY_BLOCK, 0);
}

void MpUtilLcdNormalPowerUnlockForPause(void)
{
	VideoLogInfo("");

	pm_unlock_state(LCD_NORMAL, PM_RESET_TIMER);
}

void MpUtilLcdOffForPowerButton(void)
{
	VideoLogInfo("");

	pm_unlock_state(LCD_NORMAL, PM_RESET_TIMER);
}

void MpUtilMultimediaKeyGrab(void)
{
	VideoLogInfo("");
	MpUtilSetKeyGrab(PLAY_KEY, KEY_GRAB_OR_EXCLUSIVE);
	MpUtilSetKeyGrab(STOP_KEY, KEY_GRAB_OR_EXCLUSIVE);
	MpUtilSetKeyGrab(PAUSE_KEY, KEY_GRAB_OR_EXCLUSIVE);
	MpUtilSetKeyGrab(NEXT_KEY, KEY_GRAB_OR_EXCLUSIVE);
	MpUtilSetKeyGrab(PREV_KEY, KEY_GRAB_OR_EXCLUSIVE);
	MpUtilSetKeyGrab(REWIND_KEY, KEY_GRAB_OR_EXCLUSIVE);
	MpUtilSetKeyGrab(FORWARD_KEY, KEY_GRAB_OR_EXCLUSIVE);
}

void MpUtilMultimediaKeyUngrab(void)
{
	VideoLogInfo("");

	MpUtilSetKeyUngrab(PAUSE_KEY);
	MpUtilSetKeyUngrab(PLAY_KEY);
	MpUtilSetKeyUngrab(STOP_KEY);
	MpUtilSetKeyUngrab(NEXT_KEY);
	MpUtilSetKeyUngrab(PREV_KEY);
	MpUtilSetKeyUngrab(FORWARD_KEY);
	MpUtilSetKeyUngrab(REWIND_KEY);

}

void MpUtilMultimediaVolumeKeyGrab(void)
{
	VideoLogInfo("");

	MpUtilSetKeyGrab(VOLUME_UP_KEY, KEY_GRAB_EXCLUSIVE);
	MpUtilSetKeyGrab(VOLUME_DOWN_KEY, KEY_GRAB_EXCLUSIVE);

	int nRet = 0;
	nRet = vconf_set_int(VCONFKEY_STARTER_USE_VOLUME_KEY, 1);
	if(nRet != 0)
	{
		VideoLogError("VCONFKEY_STARTER_USE_VOLUME_KEY set fail: %d", nRet);
	}
}
void MpUtilMultimediaVolumeKeyUngrab(void)
{
	VideoLogInfo("");

	MpUtilSetKeyUngrab(VOLUME_UP_KEY);
	MpUtilSetKeyUngrab(VOLUME_DOWN_KEY);
}

/*
bool MpUtilSbeamIsActive(void)
{
	VideoLogInfo("bIsActiveNfcSbeam : %d", bIsActiveNfcSbeam);

	return bIsActiveNfcSbeam;
}

void MpUtilSbeamP2pTargetDiscoveredCb(nfc_discovered_type_e nType, nfc_p2p_target_h pTarget, void *pUserData)
{
	if(!pUserData)
	{
		VideoLogInfo("User data is NULL.");
		return;
	}

	VideoAppData *pAppData = (VideoAppData *)pUserData;

	VideoLogInfo("");

	if(nType == NFC_DISCOVERED_TYPE_ATTACHED)
	{
		VideoLogInfo("NFC_DISCOVERED_TYPE_ATTACHED");

		if(bIsActiveNfcSbeam)
		{
			char szWindowId[STR_LEN_MAX] = {0};

			if(strlen(pAppData->szMediaUri) <= 0)
			{
				VideoLogInfo("[ERR]No exist media uri.");
				return;
			}

			service_h svc_handle;
			service_create(&svc_handle);
			snprintf(szWindowId, STR_LEN_MAX-1, "%d", elm_win_xwindow_get(pAppData->pMainWindow));

			service_set_operation(svc_handle, "http://tizen.org/appcontrol/operation/nfc_sbeam_send");
			service_set_mime(svc_handle, "text/DirectShareVideos");
			service_set_window(svc_handle, elm_win_xwindow_get(pAppData->pMainWindow));
			service_set_uri(svc_handle, pAppData->szMediaUri);
			service_send_launch_request(svc_handle, NULL, NULL);
			service_destroy(svc_handle);
		}
		else
		{
			VideoLogInfo("bIsActiveNfcSbeam is NULL.");
		}
	}
}

void MpUtilSbeamInit(void* pUserData)
{
	if(!pUserData)
	{
		VideoLogInfo("User data is NULL.");
		return;
	}

	VideoLogInfo("");

	int bSbeamState = VCONFKEY_NFC_SBEAM_OFF;

	if(vconf_get_bool(VCONFKEY_NFC_SBEAM, &bSbeamState) != 0)
	{
		VideoLogInfo("Fail to get value.");
	}
	else
	{
		if(bSbeamState != VCONFKEY_NFC_SBEAM_ON)
		{
			VideoLogInfo("Off state about nfc sbeam");
			return;
		}
	}

	if(bIsActiveNfcSbeam == FALSE)
	{
		if(nfc_manager_initialize(NULL, NULL) != NFC_ERROR_NONE)
		{
			VideoLogInfo("[Err] Fail to initialize nfc manager.");
			return;
		}

		nfc_manager_set_p2p_target_discovered_cb(MpUtilSbeamP2pTargetDiscoveredCb, pUserData);

		bIsActiveNfcSbeam = TRUE;
	}
	else
	{
		VideoLogInfo("Already set sbeam activation.");
	}
}

void MpUtilSbeamDeinit(void)
{
	VideoLogInfo("");

	int bSbeamState = VCONFKEY_NFC_SBEAM_OFF;

	if(vconf_get_bool(VCONFKEY_NFC_SBEAM, &bSbeamState) != 0)
	{
		VideoLogInfo("Fail to get value.");
	}
	else
	{
		if(bSbeamState != VCONFKEY_NFC_SBEAM_ON)
		{
			VideoLogInfo("Off state about nfc sbeam");
			return;
		}
	}

	if(bIsActiveNfcSbeam == TRUE)
	{
		if(nfc_manager_deinitialize() != NFC_ERROR_NONE)
		{
			VideoLogInfo("[Err] Fail to deinitialize nfc manager.");
		}

		bIsActiveNfcSbeam = FALSE;
	}
	else
	{
		VideoLogInfo("Already set sbeam unactivation.");
	}
}
*/

char* MpUtilGetFileSize(unsigned int size)
{
	VideoLogInfo("");

#define FILE_SIZE_LEN_MAX			64
#define BASIC_SIZE 					1024	//used for file size check

enum VIDEO_PLAYER_FILE_SIZE_TYPE
{
	SIZE_BYTE = 0,
	SIZE_KB,
	SIZE_MB,
	SIZE_GB
};

	int nCount = 0;

	char *pTmp = (char *)calloc(1, sizeof(char) * FILE_SIZE_LEN_MAX + 1);
	if(pTmp == NULL)
	{
		return NULL;
	}

	while(size >= (BASIC_SIZE))
	{
		size /= BASIC_SIZE;
		nCount++;
	}

	if(nCount == SIZE_BYTE)
	{
		snprintf(pTmp, FILE_SIZE_LEN_MAX,"%zuB", size);
	}
	else if(nCount == SIZE_KB)
	{
		snprintf(pTmp, FILE_SIZE_LEN_MAX,"%zuKB", size);
	}
	else if(nCount == SIZE_MB)
	{
		snprintf(pTmp, FILE_SIZE_LEN_MAX,"%zuMB", size);
	}
	else if(nCount == SIZE_GB)
	{
		snprintf(pTmp, FILE_SIZE_LEN_MAX,"%zuGB", size);
	}
	else
	{
		snprintf(pTmp, FILE_SIZE_LEN_MAX,"%zuMB", 0);
	}

	VideoLogInfo("Size=%s", pTmp);

	return pTmp;
}

void MpUtilConvertTime(int nVideoTime, char* szRetTime, bool bIsHideHour)
{
#define VIDEO_TIME_MSEC_PER_SEC         1000
#define VIDEO_TIME_SEC_PER_MIN          60
#define VIDEO_TIME_MIN_PER_HOUR         60
#define VIDEO_TIME_SEC_PER_HOUR         (VIDEO_TIME_MIN_PER_HOUR * VIDEO_TIME_SEC_PER_MIN)

	if(!szRetTime)
	{
		VideoLogInfo("[ERR] No exist szRetTime pointer.");
		return;
	}
	else
	{
		memset(szRetTime, 0, STR_LEN_MAX);
	}

	if(nVideoTime <= 0)
	{
		VideoLogInfo("nVideoTime : %d", nVideoTime);
	}

	int nTime = floor(nVideoTime / VIDEO_TIME_MSEC_PER_SEC);
	int nHour = 0;
	int nMin = 0;
	int nSec = 0;
	int nTmp = 0;

	if (nTime >= VIDEO_TIME_SEC_PER_HOUR)
	{
		nSec = nTime % VIDEO_TIME_SEC_PER_MIN;
		nTmp = floor(nTime / VIDEO_TIME_SEC_PER_MIN);
		nMin = nTmp % VIDEO_TIME_MIN_PER_HOUR;
		nHour = floor(nTmp / VIDEO_TIME_MIN_PER_HOUR);
	}
	else if (nTime >= VIDEO_TIME_SEC_PER_MIN)
	{
		nHour = 0;
		nMin = floor(nTime / VIDEO_TIME_SEC_PER_MIN);
		nSec = nTime % VIDEO_TIME_SEC_PER_MIN;
	}
	else
	{
		nHour = 0;
		nMin = 0;
		nSec = nTime % VIDEO_TIME_SEC_PER_MIN;
	}

	if(bIsHideHour)
	{
		if(nHour)
		{
			snprintf(szRetTime, STR_LEN_MAX - 1, "%02d:%02d:%02d", nHour, nMin, nSec);
		}
		else
		{
			snprintf(szRetTime, STR_LEN_MAX - 1, "%02d:%02d", nMin, nSec);
		}
	}
	else
	{
		snprintf(szRetTime, STR_LEN_MAX - 1, "%02d:%02d:%02d", nHour, nMin, nSec);
	}

	szRetTime[strlen(szRetTime)] = '\0';

	VideoLogInfo("szRetTime : %s", szRetTime);
}

void MpUtilLayoutVisibleOff(void *pWindowHandle)
{
	VideoLogInfo("");

	if(pWindowHandle == NULL)
	{
		VideoLogError("Window handle is NULL");
		return;
	}

	if(pX11DisplayHandle == NULL)
	{
		VideoLogError("Display handle is NULL");
		return;
	}

	if (!strcmp ("mobile", elm_win_profile_get (pWindowHandle)))
	{
		utilx_set_fb_visible (pX11DisplayHandle, UTILX_FB_TYPE_UI, FALSE);
	}
	else
	{
		VideoLogError("Skip for Desktop mode : %s", elm_win_profile_get (pWindowHandle));
	}
	return;
}
