/*
 * Copyright (c) [2012] Samsung Electronics Co., Ltd.
 *
 * Licensed under the Flora License, Version 1.1 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include "mp-util.h"
#include "mp-video-log.h"
#include "video-player.h"
#include "mp-video-value-define.h"
#include "mp-video-animation-ctrl.h"

#define BUFFERING_TXT_MAX_LEN	16

static Evas_Object *pAnimationEdj = NULL;
static Ecore_Timer *pAnimationTimer = NULL;

static int nIconIndex = 0;

static Eina_Bool MpVideoAnimationCtrlTimerCb(void *data)
{
/*	VideoLogInfo(""); */

	char sig_format[SIGNAL_TEXT_MAX_LEN] = { 0, };

	snprintf(sig_format, SIGNAL_TEXT_MAX_LEN, "%s.%d",
		 SIGNAL_ANIMATION_IMAGE_LOADING, nIconIndex);

	edje_object_signal_emit(pAnimationEdj, sig_format, "*");

	nIconIndex += 1;
	if (nIconIndex > ANIMATION_MAX_COUNT)
		nIconIndex = 1;

	return EINA_TRUE;
}

void *MpVideoAnimationCtrlInit(void *pUserData)
{
	VideoLogInfo("");

	if (pUserData == NULL) {
		VideoLogInfo("data is NULL");
		return NULL;
	}

	Evas *pMainWindowEvas = (Evas *) pUserData;

	pAnimationEdj = MpUtilLoadEdjFile(pMainWindowEvas,
					  VIDEO_PLAYER_ANIMATION_EDJ,
					  ANIMATION_EDJ_GROUP);

	evas_object_hide(pAnimationEdj);

	return (void *)pAnimationEdj;
}

void MpVideoAnimationCtrlDestroy(void)
{
	VideoLogInfo("");

	if (pAnimationTimer) {
		ecore_timer_del(pAnimationTimer);
		pAnimationTimer = NULL;
	}

	if (pAnimationEdj) {
		evas_object_hide(pAnimationEdj);
		evas_object_del(pAnimationEdj);
		pAnimationEdj = NULL;
	}

	nIconIndex = 0;
}

void MpVideoAnimationCtrlSetPercent(int nPercent)
{
	VideoLogInfo("");
	if (nPercent >= 0) {
		char szBuffering[BUFFERING_TXT_MAX_LEN] = { 0, };

		snprintf(szBuffering, BUFFERING_TXT_MAX_LEN, "Loading %d%%...",
			 nPercent);
		edje_object_part_text_set(pAnimationEdj, "loading.txt",
					  szBuffering);
	} else {
		edje_object_part_text_set(pAnimationEdj, "loading.txt",
					  "Loading...");
	}
}

void MpVideoAnimationCtrlPlay(void)
{
	VideoLogInfo("");
	if (pAnimationTimer == NULL) {
		pAnimationTimer = ecore_timer_add(ANIMATION_TIMER_INTERVAL,
						  MpVideoAnimationCtrlTimerCb,
						  NULL);
	}
}

void MpVideoAnimationCtrlStop(void)
{
	VideoLogInfo("");

	if (pAnimationTimer) {
		ecore_timer_del(pAnimationTimer);
		pAnimationTimer = NULL;
	}
}

void MpVideoAnimationCtrlShow(void)
{
	VideoLogInfo("");

	if (pAnimationTimer == NULL) {
		MpVideoAnimationCtrlPlay();
		MpVideoAnimationCtrlSetPercent(-1);
		evas_object_show(pAnimationEdj);
	}
}

void MpVideoAnimationCtrlHide(void)
{
	VideoLogInfo("");

	MpVideoAnimationCtrlStop();
	evas_object_hide(pAnimationEdj);
}

bool MpVideoAnimationCtrlGetActiveState(void)
{
	VideoLogInfo("");
	if (pAnimationTimer)
		return true;
	else
		return false;
}
