/*
 * Copyright (c) [2012] Samsung Electronics Co., Ltd.
 *
 * Licensed under the Flora License, Version 1.1 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <app.h>
#include <player.h>
#include <sound_manager.h>
#include <Ecore_Evas.h>
#include <Elementary.h>

#include "mp-util.h"
#include "mp-video-log.h"
#include "video-player.h"
#include "mp-video-type-define.h"
#include "mp-video-value-define.h"
#include "mp-video-string-define.h"
#include "mp-video-sound-path-ctrl.h"

#define MP_VIDEO_SOUND_PATH_NUM			10
#define MP_VIDEO_SOUND_PATH_SPEAKER		"Speaker"
#define MP_VIDEO_SOUND_PATH_EARJACK		"Headphones"

static Evas_Object *pVideoSoundPathPopUpHandle = NULL;
//static Evas_Object *pVideoSoundPathpPopupWindow = NULL;
static Evas_Object *pGroupRadio = NULL;
static Evas_Object *pGenList = NULL;

static char **szSoundPathItems = NULL;
static bool bIsConnectBluetooth = FALSE;
static bool bIsConnectEarjack = FALSE;

void MpVideoSoundpathDeleteRadioButton(void)
{
	VideoLogInfo("");

	if (pGroupRadio) {
		evas_object_del(pGroupRadio);
		pGroupRadio = NULL;
	}
}

void MpVideoSoundpathDeletePopupHandle(void)
{
	VideoLogInfo("");

	int nCount = 0;

	if(szSoundPathItems)
	{
		for(nCount = 0; nCount < MP_VIDEO_SOUND_PATH_NUM; nCount++)
		{
			if(szSoundPathItems[nCount])
			{
				free(szSoundPathItems[nCount]);
				szSoundPathItems[nCount] = NULL;
			}
		}
		free(szSoundPathItems);
		szSoundPathItems = NULL;
	}

	MpVideoSoundpathDeleteRadioButton();

	if (pGenList) {
		evas_object_del(pGenList);
		pGenList = NULL;
	}

	if (pVideoSoundPathPopUpHandle) {
		evas_object_del(pVideoSoundPathPopUpHandle);
		pVideoSoundPathPopUpHandle = NULL;
	}

	MpUtilSetAlphaOfMainWindow(TRUE);

	/*
	if (pVideoSoundPathpPopupWindow) {
		evas_object_del(pVideoSoundPathpPopupWindow);
		pVideoSoundPathpPopupWindow = NULL;
	}
	*/
}

static char *MpVideoSoundpathGetLabelOfGenlistItemCb(const void *pUserData,
						     Evas_Object *pObject,
						     const char *pPart)
{
	VideoLogInfo("");

	int nIndex = (int)pUserData;

	if (!strcmp(pPart, "elm.text")) {
		VideoLogInfo("Index : %d", nIndex);
		return strdup(szSoundPathItems[nIndex]);
	}

	return NULL;
}

static Evas_Object *MpVideoSoundpathGetIconOfGenlistItemCb(const void
							   *pUserData,
							   Evas_Object *pObject,
							   const char *pPart)
{
	VideoLogInfo("");

	int nIndex = (int)pUserData;
	Evas_Object *pTmpRadio = NULL;

	if (!strcmp(pPart, "elm.icon")) {
		VideoLogInfo("Index : %d", nIndex);
		pTmpRadio = elm_radio_add(pObject);
		elm_radio_state_value_set(pTmpRadio, nIndex);
		evas_object_show(pTmpRadio);
		elm_radio_group_add(pTmpRadio, pGroupRadio);
	}

	return pTmpRadio;
}

static void MpVideoSoundpathSelectSoundPathItemCb(void *pUserData, Evas_Object *pObject, void *pEventInfo)
{
	if(pUserData == NULL)
	{
		VideoLogInfo("[ERR]No have pUserData");
		return;
	}

	VideoLogInfo("");

	VideoAppData *pAppData = (VideoAppData *)pUserData;

	int nIndex = 0;
	Elm_Object_Item *pItem = (Elm_Object_Item *) pEventInfo;

	if(pItem)
	{
		nIndex = (int)elm_object_item_data_get(pItem);
		VideoLogInfo("Select sound path : %s", szSoundPathItems[nIndex]);

		if(!strcmp(szSoundPathItems[nIndex], MP_VIDEO_SOUND_PATH_SPEAKER))
		{
			int nRet = 0;
			nRet = sound_manager_set_active_route(SOUND_ROUTE_OUT_SPEAKER);

			elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_SPEAKER);
		}
		else if (!strcmp(szSoundPathItems[nIndex], MP_VIDEO_SOUND_PATH_EARJACK))
		{
			int nRet = sound_manager_set_active_route(SOUND_ROUTE_OUT_WIRED_ACCESSORY);
			if(nRet != SOUND_MANAGER_ERROR_NONE)
			{
 				VideoLogInfo("[ERR] set_system_policy(0x%x)", nRet);
			}
			else
			{
				elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_EARJACK);
			}
		}
		else
		{
			//int nRet = sound_manager_set_route_policy(SOUND_ROUTE_DEFAULT);
			int nRet = sound_manager_set_active_route(SOUND_ROUTE_OUT_BLUETOOTH);
			if(nRet != SOUND_MANAGER_ERROR_NONE)
			{
				VideoLogInfo("[ERR] set_system_policy(0x%x)", nRet);
			}
			else
			{
				elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_BLUETOOTH);
			}
		}
	}

	MpVideoSoundpathDeletePopupHandle();
}

static void MpVideoSoundpathPopupCb(void *pUserData, Evas_Object *pObject,
				    void *pEventInfo)
{
	VideoLogInfo("");

	if (pUserData == NULL) {
		VideoLogInfo("[ERR]No have pUserData");
		return;
	}

	MpVideoSoundpathDeletePopupHandle();
}

static void MpVideoSoundpathCurrentState()
{
	VideoLogInfo("");

	bool bBluetoothConnect = 0;
	char *szBluetoothName = NULL;
	bIsConnectEarjack = FALSE;
	bIsConnectBluetooth = FALSE;

	/* Speaker */
	strncpy(szSoundPathItems[MP_SOUND_PATH_SPEAKER], MP_VIDEO_SOUND_PATH_SPEAKER, STR_LEN_MAX - 1);

	/*  Check and Add earjack sound path. */
	if(MpUtilIsConnectEarjack())
	{
		VideoLogInfo("Connect earjack.");
		bIsConnectEarjack = TRUE;
		strncpy(szSoundPathItems[MP_SOUND_PATH_EARJACK], MP_VIDEO_SOUND_PATH_EARJACK, STR_LEN_MAX - 1);
	}
	else
	{
		VideoLogInfo("No connect earjack.");
	}

	/*  Add bluetooth stereo sound path. */
	if(SOUND_MANAGER_ERROR_NONE != sound_manager_get_a2dp_status(&bBluetoothConnect, &szBluetoothName))
	{
		VideoLogInfo("[ERR] Fail to check bluetooth stereo sound path.");
	}
	else
	{
		if(bBluetoothConnect)
		{
			if(szBluetoothName)
			{
				VideoLogInfo("Connect szBluetoothName : %s", szBluetoothName);
				bIsConnectBluetooth = TRUE;
				strncpy(szSoundPathItems[MP_SOUND_PATH_BLUETOOTH], szBluetoothName, STR_LEN_MAX - 1);
				free(szBluetoothName);
				szBluetoothName = NULL;
			}
		}
		else
		{
			if(szBluetoothName)
			{
				free(szBluetoothName);
				szBluetoothName = NULL;
			}
			VideoLogInfo("Unactivate Bluetooth stereo A2DP.");
		}
	}

}

void MpVideoSoundpathSetRadioButton(void)
{
	VideoLogInfo("");

	sound_device_in_e in;
	sound_device_out_e out;

	sound_manager_get_active_device(&in, &out);

	switch(out)
	{
	case SOUND_DEVICE_OUT_SPEAKER:
		elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_SPEAKER);
		break;

	case SOUND_DEVICE_OUT_WIRED_ACCESSORY:
		elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_EARJACK);
		break;

	case SOUND_DEVICE_OUT_BT_A2DP:
		elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_BLUETOOTH);
		break;

	default:
		elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_SPEAKER);
		break;
	}

/*
	bool bBluetoothConnect = 0;
	char *szBluetoothName = NULL;
	sound_route_policy_e nPolicy = 0;

	if(sound_manager_get_route_policy(&nPolicy) != SOUND_MANAGER_ERROR_NONE)
	{
		VideoLogInfo("[ERR] Fail to get sound path route policy.");
		return;
	}

	if(nPolicy == SOUND_ROUTE_DEFAULT)
	{
		VideoLogInfo("SYSTEM_AUDIO_ROUTE_POLICY_DEFAULT");

		if(SOUND_MANAGER_ERROR_NONE != sound_manager_get_a2dp_status(&bBluetoothConnect, &szBluetoothName))
		{
			VideoLogInfo("[ERR] Fail to check bluetooth stereo sound path.");
		}

		if(bBluetoothConnect)
		{
			elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_BLUETOOTH);
		}
		else if(MpUtilIsConnectEarjack())
		{
			elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_EARJACK);
		}
		else
		{
			elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_SPEAKER);
		}
	}
	else if(nPolicy == SOUND_ROUTE_IGNORE_A2DP)
	{
		VideoLogInfo("SYSTEM_AUDIO_ROUTE_POLICY_IGNORE_A2DP");

		if(MpUtilIsConnectEarjack())
		{
			elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_EARJACK);
		}
		else
		{
			elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_SPEAKER);
		}
	}
	else
	{
		VideoLogInfo("SYSTEM_AUDIO_ROUTE_POLICY_HANDSET_ONLY");

		elm_radio_value_set(pGroupRadio, MP_SOUND_PATH_SPEAKER);
	}
*/
}

/*
 * External function
 */
bool MpVideoSoundpathShow(void *pUserData)
{
	if (pUserData == NULL) {
		VideoLogInfo("No have popup message or pAppData is null.");
		return FALSE;
	}

	VideoLogInfo("");

	MpVideoSoundpathIsConnectOtherSoundpath();

	if (!bIsConnectBluetooth && !bIsConnectEarjack) {
		VideoLogInfo("Soundpath is only speaker.");
		return FALSE;
	}

	Evas_Object *pBox = NULL;
	Evas_Object *pButton = NULL;
	VideoAppData *pAppData = (VideoAppData *)pUserData;

	MpVideoSoundpathDeletePopupHandle();

	MpUtilSetAlphaOfMainWindow(FALSE);

	/*  Popup handle */
	//pVideoSoundPathpPopupWindow = (Evas_Object *)MpUtilCreateWindow("soundpath_popup_window");
	//pVideoSoundPathPopUpHandle = elm_popup_add(pVideoSoundPathpPopupWindow);
	pVideoSoundPathPopUpHandle = elm_popup_add(pAppData->pMainWindow);


	szSoundPathItems = (char **)calloc(1, sizeof(char *) * MP_VIDEO_SOUND_PATH_NUM);
	int idx = 0;
	for(idx = 0; idx < MP_VIDEO_SOUND_PATH_NUM; idx++)
	{
		szSoundPathItems[idx] = (char *)calloc(1, STR_LEN_MAX * sizeof(char));
	}

	MpVideoSoundpathCurrentState();

	elm_object_style_set(pVideoSoundPathPopUpHandle, "menustyle");
	elm_object_part_text_set(pVideoSoundPathPopUpHandle, "title,text", MP_VIDEO_SOUND_PATH);
	evas_object_size_hint_weight_set(pVideoSoundPathPopUpHandle, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);

	pButton = elm_button_add(pVideoSoundPathPopUpHandle);
	elm_object_style_set (pButton, "popup_button/default");
	elm_object_text_set(pButton, dgettext(MP_SYS_STRING, MP_COM_BUTTON_CANCEL));
	elm_object_part_content_set(pVideoSoundPathPopUpHandle, "button1", pButton);
	evas_object_smart_callback_add(pButton, "clicked", MpVideoSoundpathPopupCb, (void*)pAppData);

	/*  Set item of Genlist. */
	Elm_Genlist_Item_Class *st_Itc = NULL;
	st_Itc = elm_genlist_item_class_new();
	st_Itc->item_style = "1text.1icon.3";
	st_Itc->func.text_get = (void *)MpVideoSoundpathGetLabelOfGenlistItemCb;
	st_Itc->func.content_get = (void *)MpVideoSoundpathGetIconOfGenlistItemCb;
	st_Itc->func.state_get = NULL;
	st_Itc->func.del = NULL;

	/* Create genlist handle */
	pGenList = elm_genlist_add(pVideoSoundPathPopUpHandle);
	evas_object_size_hint_weight_set(pGenList, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	evas_object_size_hint_align_set(pGenList, EVAS_HINT_FILL, EVAS_HINT_FILL);

	//MpUtilRotateWindow(MpUtilGetRotationState(), pVideoSoundPathpPopupWindow);

	pGroupRadio = elm_radio_add(pGenList);

	if (bIsConnectBluetooth) {
		elm_genlist_item_append(pGenList, st_Itc, (void *)MP_SOUND_PATH_BLUETOOTH, NULL,
					ELM_GENLIST_ITEM_NONE,
					MpVideoSoundpathSelectSoundPathItemCb,
					pAppData);
	}

	if (bIsConnectEarjack) {
		elm_genlist_item_append(pGenList, st_Itc, (void *)MP_SOUND_PATH_EARJACK, NULL,
					ELM_GENLIST_ITEM_NONE,
					MpVideoSoundpathSelectSoundPathItemCb,
					pAppData);
	}

	elm_genlist_item_append(pGenList, st_Itc, (void *)MP_SOUND_PATH_SPEAKER, NULL,
					ELM_GENLIST_ITEM_NONE,
					MpVideoSoundpathSelectSoundPathItemCb,
					pAppData);

	elm_genlist_item_class_free(st_Itc);

	MpVideoSoundpathSetRadioButton();

	pBox = elm_box_add(pVideoSoundPathPopUpHandle);
	if(bIsConnectBluetooth && bIsConnectEarjack)
	{
		evas_object_size_hint_min_set(pBox, 614 * elm_config_scale_get(), 338 * elm_config_scale_get());
	}
	else if(bIsConnectBluetooth || bIsConnectEarjack)
	{
		evas_object_size_hint_min_set(pBox, 614 * elm_config_scale_get(), 225 * elm_config_scale_get());
	}
	else
	{
		evas_object_size_hint_min_set(pBox, 614 * elm_config_scale_get(), 451 * elm_config_scale_get());
	}

	elm_box_pack_end(pBox, pGenList);
	elm_object_content_set(pVideoSoundPathPopUpHandle, pBox);

	evas_object_show(pGenList);
	evas_object_show(pVideoSoundPathPopUpHandle);

	return TRUE;
}

void MpVideoSoundpathHide(void)
{
	VideoLogInfo("");

	MpVideoSoundpathDeletePopupHandle();
}

void MpVideoSoundpathRotatePopupWindow(int nRotateMode)
{
	/*
	if (!pVideoSoundPathpPopupWindow) {
		VideoLogInfo("No exist genlist popup window handle.");
		return;
	}

	VideoLogInfo("");

	MpUtilRotateWindow(nRotateMode, pVideoSoundPathpPopupWindow);
	*/

	return;
}

bool MpVideoSoundpathIsConnectOtherSoundpath(void)
{
	VideoLogInfo("");

	bool bBluetoothConnect = 0;
	char *szBluetoothName = NULL;

	bIsConnectEarjack = FALSE;
	bIsConnectBluetooth = FALSE;

	if(MpUtilIsConnectEarjack())
	{
		VideoLogInfo("Connect earjack.");
		bIsConnectEarjack= TRUE;
		return TRUE;
	}
	sound_manager_get_a2dp_status(&bBluetoothConnect, &szBluetoothName);

	if(bBluetoothConnect)
	{
		if(szBluetoothName) {
			free(szBluetoothName);
			szBluetoothName = NULL;
		}

		VideoLogInfo("Connect bluetooth.");
		bIsConnectBluetooth = TRUE;
		return TRUE;
	}

	if(szBluetoothName) {
		free(szBluetoothName);
		szBluetoothName = NULL;
	}

	VideoLogInfo("Only spaker.");
	return FALSE;
}

int MpVideoSoundpathGetCurrConnectedSoundpath(void)
{
	VideoLogInfo("");

	sound_device_in_e in;
	sound_device_out_e out;
	MpSoundPathType nType = MP_SOUND_PATH_SPEAKER;

	sound_manager_get_active_device(&in, &out);

	switch(out)
	{
	case SOUND_DEVICE_OUT_SPEAKER:
		nType =  MP_SOUND_PATH_SPEAKER;
		break;

	case SOUND_DEVICE_OUT_WIRED_ACCESSORY:
		nType =  MP_SOUND_PATH_EARJACK;
		break;

	case SOUND_DEVICE_OUT_BT_A2DP:
		nType =  MP_SOUND_PATH_BLUETOOTH;
		break;

	default:
		nType =  MP_SOUND_PATH_SPEAKER;
		break;
	}

	return nType;

/*
	bool bBluetoothConnect = 0;
	char *szBluetoothName = NULL;
	sound_route_policy_e nPolicy = 0;

	if(sound_manager_get_route_policy(&nPolicy) != SOUND_MANAGER_ERROR_NONE)
	{
		VideoLogInfo("[ERR] Fail to get sound path route policy.");
		return MP_SOUND_PATH_SPEAKER;
	}

	if(nPolicy == SOUND_ROUTE_DEFAULT)
	{
		VideoLogInfo("SYSTEM_AUDIO_ROUTE_POLICY_DEFAULT");

		if(SOUND_MANAGER_ERROR_NONE != sound_manager_get_a2dp_status(&bBluetoothConnect, &szBluetoothName))
		{
			VideoLogInfo("[ERR] Fail to check bluetooth stereo sound path.");
		}

		if(bBluetoothConnect)
		{
			return MP_SOUND_PATH_BLUETOOTH;
		}
		else if(MpUtilIsConnectEarjack())
		{
			return MP_SOUND_PATH_EARJACK;
		}
		else
		{
			return MP_SOUND_PATH_SPEAKER;
		}
	}
	else if(nPolicy == SOUND_ROUTE_IGNORE_A2DP)
	{
		VideoLogInfo("SYSTEM_AUDIO_ROUTE_POLICY_IGNORE_A2DP");

		if(MpUtilIsConnectEarjack())
		{
			return MP_SOUND_PATH_EARJACK;
		}
		else
		{
			return MP_SOUND_PATH_SPEAKER;
		}
	}
	else
	{
		VideoLogInfo("SYSTEM_AUDIO_ROUTE_POLICY_HANDSET_ONLY");

		return MP_SOUND_PATH_SPEAKER;
	}

	return MP_SOUND_PATH_SPEAKER;
*/
}
